("\"encryption\" features from the preference panel" "funkcionalita \"šifrovanie\" z panelu nastavení")
("(Re)Build autocompletion index" "(Nanovo) vytvoriť index automatického dopĺňania")
("a modifier" "modifikátor a")
("a series" "séria a")
("a.C.M. computing class" "trieda A.C.M")
("a.M.S. subject class" "trieda A.M.S")
("abbreviated authors" "autori skrátene")
("abbreviation" "skratka")
("about" "o")
("about menu" "o TeXmacse")
("above" "nad")
("abstract" "abstrakt")
("accent" "akcent")
("accent above" "akcent nad")
("accent below" "akcent pod")
("accept" "akceptovať")
("accept all scripts" "povoliť všetky skripty")
("accept during this pass" "povoliť počas tohoto prechodu")
("accept no scripts" "nepovoliť  žiadne skripty")
("accept script" "povoliť skript")
("acknowledge" "poďakovať")
("acknowledgment" "poďakovanie")
("acknowledgments" "poďakovanie")
("acronym" "akronym")
("action" "akcia")
("activate" "aktivovať")
("activate hidden" "aktivovať skryté")
("activate once" "aktivovať raz")
("activation" "aktivácia")
("active link types" "aktívne typy odkazov")
("acute" "dĺžeň")
("add" "pridať")
("add abstract information" "pridať abstraktnú informáciu")
("add author information" "pridať informáciu o autorovi")
("add branch after" "pridať vetvu za")
("add branch before" "pridať vetvu pred")
("add other package" "pridať iný balíček")
("add package" "pridať balíček")
("add remote ssh connection" "pridať vzdialené pripojenie ssh")
("add style package" "pridať balík štýlu")
("add switch after" "pridať prepínač za")
("add switch before" "pridať prepínač pred")
("add title information" "pridať informáciu ohľadom nadpisu")
("add to custom colors" "pridať do vlastných farieb")
("addition" "prídavok")
("address" "adresa")
("address block" "blok adresy")
("adjust" "upraviť")
("adjust limits" "upraviť limity")
("advanced" "pokročilé")
("advanced font customization" "pokročilé prispôsobenie písma")
("advanced layout features" "pokročilé vlastnosti rozloženia")
("affiliation" "afiliácia")
("after" "po")
("albanian" "albánčina")
("algorithm" "algoritmus")
("algorithms" "algoritmy")
("align cell to the bottom" "zarovnať bunku na spodok")
("align cell to the decimal comma" "zarovnať bunku na desatinnú čiarku")
("align cell to the decimal dot" "zarovnať bunku na desatinnú bodku")
("align cell to the left" "zarovnať bunku doľava")
("align cell to the right" "zarovnať bunku doprava")
("align cell to the top" "zarovnať bunku na vrch")
("align table at axis" "zarovnať bunku na osi")
("align table at base of left column" "zarovnať tabuľku podľa ľavého stĺpca")
("align table at base of middle column" "zarovnať tabuľku podľa stredného stĺpca")
("align table at base of origin column" "zarovnať tabuľku podľa pôvodného stĺpca")
("align table at base of right column" "zarovnať tabuľku podľa pravého stĺpca")
("align table at fraction bar height" "zarovnať tabuľku na zlomkovú čiaru")
("align table at the base of bottom row" "zarovnať tabuľku podľa spodného riadku")
("align table at the base of middle row" "zarovnať tabuľku podľa stredného riadku")
("align table at the base of origin row" "zarovnať tabuľku podľa pôvodného riadku")
("align table at the base of top row" "zarovnať tabuľku podľa vrchného riadku")
("align table at the bottom" "zarovnať tabuľku na spodok")
("align table at the center" "zarovnať tabuľku na stred")
("align table at the horizontal center" "zarovnať tabuľku na vodorovný stred")
("align table at the left" "zarovnať tabuľku doľava")
("align table at the top" "zarovnať tabuľku na vrch")
("align table to the right" "zarovnať tabuľku doprava")
("align text to the left" "zarovnať text doľava")
("align text to the right" "zarovnať text doprava")
("aligned" "zarovnaný")
("alignment" "zarovnanie")
("alignment of balloon" "zarovnanie bubliny")
("all" "všetko")
("all cells" "všetky bunky")
("all data attached to this identity will be lost" "všetky dáta pripojené k tejto identite budú stratené")
("all saved passphrases will be lost forever" "všetky uložené heslá budú navždy stratené")
("allow" "povoliť")
("allow for macro definitions in preamble" "povoliť definície makier v preambule")
("allow multiple spaces" "povoliť viacnásobné medzery")
("allow spurious spaces" "povoliť falošné medzery")
("allowed extension" "povolené rozšírenie")
("allowed page height extension" "povolené zväčšenie výšky")
("allowed page height reduction" "povolená redukcia výšky")
("allowed positions" "povolené polohy")
("allowed positions of floating object" "povolené polohy plávajúcich objektov")
("allowed reduction" "povolená redukcia")
("alpha release" "alfaverzia")
("alpha transparency" "alfa priesvitnosť")
("also on paper" "aj na papieri")
("alt key" "kláves alt")
("alter" "zmeniť")
("alternate" "alternovať")
("alternate except here" "alternovať okrem tohoto miesta")
("alternate from here on" "alternovať odtiaľto")
("alternate only here" "alternovať iba tu")
("alternate until here" "alternovať potiaľto")
("alternative colors" "alternatívne farby")
("alternative specification" "alternatívna špecifikácia")
("always" "vždy")
("american" "americká angličtina")
("amplified" "zosilnený")
("anchor" "kotva")
("ancient" "starobylý")
("and" "a")
("and perform casual settings from the \"Encryption\" tab" "a vykonať prípadné nastavenia z karty \"Šifrovanie\"")
("angle" "uhol")
("angular" "uhlový")
("animate" "animovať")
("animate folding" "animovať zbaľovanie")
("animate object" "animovať objekt")
("animate objects" "animovať objekty")
("animate unfolding" "animovať odbaľovanie")
("animated" "animované")
("animation" "animácia")
("animation toolbar" "nástrojová lišta pre animácie")
("annotate" "anotovať")
("annote" "anotovať")
("answer" "odpoveď")
("answer field" "pole pre odpoveď")
("answer to question" "odpoveď na otázku")
("answers" "odpovede")
("answers only" "iba odpovede")
("any" "ľubovoľné")
("appear" "objaviť sa")
("appendix" "dodatok")
("apply" "použiť")
("apply macro" "použiť makro")
("apply macro once" "použiť makro raz")
("april" "apríl")
("arab" "arabčina")
("arc" "arkus")
("arc cosine" "arkuskosínus")
("arc sine" "arkussínus")
("arc tangent" "arkustangens")
("arch series" "arch series")
("archaic" "archaický")
("architecture" "architektúra")
("are you sure you want to delete collected public keys" "ste si istý, že chcete zmazať zozbierané verejné kľúče")
("are you sure you want to delete selected public keys" "ste si istý, že chcete zmazať zvolené verejné kľúče")
("are you sure you want to delete selected secret keys" "ste si istý, že chcete zmazať zvolené privátne kľúče")
("are you sure you want to destroy the wallet" "ste si istý, že chcete zničiť peňaženku")
("argument" "argument")
("arithmetic" "aritmetický")
("armenian" "arménčina")
("arrow" "šípka")
("arrows" "šípky")
("art Pen" "umelecké Pero")
("art frame" "umelecký rám")
("article" "článok")
("arxiv category" "kategória arxiv")
("as on paper" "ako na papieri")
("as visual grid" "ako vizuálna mriežka")
("aspect" "proporcie")
("assign" "priradiť")
("at fraction bar height" "na zlomkovú čiaru")
("at the baseline" "na učiarie (základnú dotyčnicu)")
("at the bottom" "na spodok")
("at the left" "doľava")
("at the middle" "na stred")
("at the right" "doprava")
("at the top" "na vrch")
("attach" "pripojiť")
("attach buffer to which project" "pripojiť buffer ku ktorému projektu")
("attached" "pripojené")
("august" "august")
("author" "autor")
("authorize" "autorizovať")
("auto" "auto")
("auto-save file" "automaticky ukladať súbor")
("automate" "automatizovať")
("automatic" "automatický")
("automatic brackets" "automatické zátvorky")
("automatic content generation" "automatické generovanie obsahu")
("automatic program brackets" "automatické zátvorky programu")
("automatic quotes" "automatické úvodzovky")
("automatically close brackets" "automaticky uzatvárať zátvorky")
("automatically generated content" "automaticky generovaný obsah")
("automatically import bibliographies when opening files" "automatický import bibliografií (súborov s literatúrou) pri otváraní súborov")
("automatically open this console on errors" "automaticky otvoriť túto konzolu pri chybách")
("automatically open this console on warnings" "automaticky otvoriť túto konzolu pri varovaniach")
("automatically remember all passphrases in the wallet" "automaticky si pamätať všetky heslá v peňaženke")
("automatically save" "automaticky ukladať")
("autosave" "automatické ukladanie")
("axiom" "axióma")
("axioms" "axiómy")
("axis" "os")
("b series" "séria b")
("back" "späť")
("background" "pozadie")
("background color" "farba pozadia")
("background evaluations" "vyhodnocovanie na pozadí")
("background pattern" "vzor pozadia")
("background picture" "obrázok pozadia")
("background picture selector" "výber obrázku pozadia")
("backtrace errors" "spätne stopovať chyby (backtrace)")
("backward replace" "nahrádzať smerom dozadu")
("backward search" "vyhľadávať smerom dozadu")
("bad data format" "zlý formát dát")
("bar" "pruh")
("bard" "bard")
("base" "základňa")
("base level" "základná úroveň")
("baseline" "učiarie (základná dotyčnica)")
("bashkirian" "baškirčina")
("basic" "základný")
("basic colors" "základné farby")
("basic communication using pipes" "základná komunikácia prostredníctvom unixových rúr")
("basic data types" "základné dátové typy")
("basic types" "základné typy")
("be useful" "buď užitočný")
("beamer" "projektor (beamer)")
("beamer formats" "formáty štýlu projektor (beamer)")
("beamer theme" "téma projektor (beamer)")
("become a TeXmacs developer" "staň sa vývojárom TeXmacsu")
("before" "pred")
("begin" "začni")
("below" "pod")
("bench" "")
("bend bottom" "ohnúť spodok")
("bend corner" "ohnúť roh")
("bend diagonal" "ohnúť uhlopriečku")
("bend in" "ohnúť dnu")
("bend out" "ohnúť von")
("beta release" "betaverzia")
("bezier" "bézierova krivka")
("bibTeX command" "príkaz bibTeXu")
("bibliography" "literatúra")
("bibliography file" "súbor s literatúrou")
("bibliography style" "štýl pre literatúru")
("bidirectional" "obojsmerné")
("big" "veľký")
("big environment box" "box veľkého prostredia")
("big figure" "veľký obrázok")
("big focus" "veľký fokus")
("big operator" "veľký operátor")
("big skip" "veľký odstup")
("big table" "veľká tabuľka")
("binary operation" "binárna operácia")
("binary operation" "binárny operátor")
("binary relation" "binárna relácia")
("bitmap resolution (dpi)" "rozlíšenie bitmapy (dpi)")
("black" "čierna")
("black floral I" "čierny floral I")
("black floral II" "čierny floral II")
("blackboard" "blackboard")
("blackboard bold" "blackboard hrubo")
("blackboard embold" "blackboard zvýraznený hrubo")
("blackboard math" "blackboard matematický")
("blackletter" "blackletter")
("blank column" "prázdny stĺpec")
("blank row" "prázdny riadok")
("block" "blok")
("block content" "obsah bloku")
("block of code" "blok kódu")
("blue" "modrá")
("bluish" "do modra")
("blur" "rozmazanie")
("blur radius" "polomer rozmazania")
("body" "telo")
("body color" "farba tela")
("bold" "hrubo")
("book" "kniha")
("booklet" "brožúra")
("border" "okraj")
("boring-white" "nudná biela")
("both" "oba")
("both versions" "obe verzie")
("bothlined" "s čiarou nad aj pod")
("bottom" "spodok")
("bottom baseline" "spodné učiarie (základná dotyčnica)")
("bottom border" "spodné orámovanie")
("bottom cell border" "spodné orámovanie bunky")
("bottom cell padding" "spodný odskok bunky")
("bottom center" "spodný stredný")
("bottom left" "spodný ľavý")
("bottom margin" "spodný okraj")
("bottom padding" "spodný odskok")
("bottom right" "spodný pravý")
("bottom table border" "spodné orámovanie tabuľky")
("bottom table padding" "spodný odskok tabuľky")
("bottom tools" "spodné nástroje")
("box" "box")
("branch" "vetva")
("break" "zalomenie")
("breaking" "zalamovanie")
("breve" "oblý mäkčeň")
("british" "britská angličtina")
("broken citations" "nefunkčné citácie")
("broken references" "nefunkčné odkazy")
("broken white" "zlomená biela")
("brown" "hnedá")
("browse" "prechádzať")
("browse back" "prechádzať naspäť")
("browse forward" "prechádzať vpred")
("browse modules documentation" "prechádzať dokumentáciu modulov")
("browse symbols documentation" "prechádzať dokumentáciu symbolov")
("browse web" "prehliadať web")
("browser" "prehliadač")
("buffer" "zásobník (buffer)")
("buffer in this window" "zásobník (buffer) v tomto okne")
("buffer management" "správa zásobníkov (bufferov)")
("buffer must be on disk" "zásobník (buffer) musí byť na disku")
("buffer must have a name" "zásobník (buffer) musí mať názov")
("build buffer" "zostaviť zásobník (build buffer)")
("build buffer in" "zostaviť zásobník (build buffer) v")
("build directory" "adresár (priečinok) pre zostavenie (build)")
("build directory in" "adresár (priečinok) pre zostavenie (build) v")
("build link pages" "zostaviť strany odkazov (build link pages)")
("build-all" "zostaviť všetko (build-all)")
("bulgarian" "bulharčina")
("bullet" "odrážka")
("bullets" "odrážky")
("busy" "pracujem...")
("by" "vytvoril")
("by typing" "písaním")
("bytes free" "voľných bytov")
("bytes used" "obsadených bytov")
("cJK" "cJK")
("cJK spacing" "cJK medzery")
("cSS stylesheet" "šablóna so štýlom CSS")
("calculus" "infinitezimálny počet")
("calligraphic" "kaligrafický")
("cancel" "zrušiť")
("cancelled" "zrušené")
("cannot download directory to file" "nie je možné stiahnuť adresár (priečinok) do súboru")
("cannot rename across different servers" "premenovanie cez rôzne servery nie je možné")
("cannot upload directory to file" "nie je možné nahrať adresár (priečinok) do súboru")
("caps-lock key" "kláves caps-lock")
("caption" "názov/popis (caption)")
("cartesian" "kartézsky")
("cartoon" "karikatúra (cartoon)")
("carved wood" "vyrezávané drevo")
("case" "veľké/malé písmená")
("case-insensitive search" "vyhľadávanie necitlivé na veľké a malé písmená")
("categories" "kategórie")
("category" "kategória")
("cc" "slepá kópia")
("cell" "bunka")
("cell background color" "farba pozadia bunky")
("cell border" "orámovanie bunky")
("cell height" "výška bunky")
("cell operation mode" "režim operácií s bunkou")
("cell properties" "vlastnosti bunky")
("cell span" "rozpätie bunky (span)")
("cell width" "šírka bunky")
("cells" "bunky")
("center" "stred")
("center baseline" "stredné učiarie (základná dotyčnica) ")
("center text" "vycentrovať text")
("centered" "vycetrované")
("centered block" "vycentrovaný blok")
("centered programs" "vycentrované programy")
("centered tabular" "vycentrovaná tabuľka")
("chalk" "krieda")
("change border of cell" "zmena orámovania bunky")
("change cell operation mode" "zmena módu operácií s bunkou")
("change default unit" "zmena predvolenej jednotky")
("change log" "záznam zmien")
("change passphrase" "zneniť heslo")
("change permissions" "zmeniť povolenia")
("change step-size" "zmeniť veľkosť kroku")
("change tags" "zmeniť značky")
("change the TeXmacs preferences" "zmeniť nastavenia TeXmacsu")
("change the border of the table" "zmeniť orámovanie tabuľky")
("change the style of mathematical formulas" "zmeniť štýl matematických vzorcov")
("change wallet passphrase" "zmeniť heslo peňaženky")
("changes" "zmeny")
("chapter" "kapitola")
("character compression" "kompresia znakov")
("character contraction" "kontrakcia znakov")
("character count" "počet znakov")
("character encoding" "kódovanie znakov")
("character expansion" "expanzia znakov")
("check" "mäkčeň")
("check exported Pdf files for correctness" "kontrola správnosti exportovaných Pdf súborov")
("check for automatic updates" "kontrola automatických aktualizácií")
("check for updates" "skontrolovať aktualizácie")
("check text for spelling errors" "skontrolovať pravopis")
("checkable field" "kontrolovateľné polia")
("chinese" "čínština")
("choice" "voľba")
("choose background" "zvoliť pozadie")
("choose color" "zvoliť farbu")
("cipher algorithm for passphrase encryption" "šifrovací algoritmus pre šifrovanie hesla")
("circle" "kruh")
("citation" "citácia")
("cite" "citovať")
("cite TeXmacs" "citovať TeXmacs")
("cite TeXmacs-related work" "citovať prácu súvisiacu s TeXmacsom")
("cite related work" "citovať súvisiacu prácu")
("class" "trieda")
("classic" "klasické")
("classification" "klasifikácia")
("clean slate" "čistý štít")
("clear" "vymazať")
("clear all fields" "vymazať všetky polia")
("clear local information" "vymazať lokálne informácie")
("clear menu" "vymazať menu")
("clear selection" "vymazať označené")
("clear undo history" "vymazať históriu pre 'undo'")
("click Ok button twice to discard this warning" "zavrieť varovanie dvojklikom na tlačidlo OK ")
("client" "")
("clip" "orezať")
("clipboard image format" "formát obrázku v clipboarde")
("clipped" "orezané")
("clipped and magnified" "orezané a zv䣲ené")
("clipped and resized" "orezané a zmenené rozmery")
("clone" "duplikovať")
("clone window" "duplikovať okno")
("close" "zavrieť")
("close TeXmacs" "zavrieť TeXmacs")
("close animation tool" "zavrieť animačný nástroj")
("close buffer" "zavrieť buffer")
("close document" "zavrieť dokument")
("close program" "zavrieť program")
("close replace tool" "zavrieť nástroj pre nahradzovanie")
("close search tool" "zavrieť nástroj vyhľadávania")
("close session" "ukončiť session")
("close spell tool" "zavrieť nástroj na kontrolu pravopisu")
("close translations to rebuild" "zavrieť preklady na znovuzostavenie (rebuild)")
("close window" "zavrieť okno")
("closed bezier" "uzavreté bézierova krivka")
("closed curve" "uzavretá krivka")
("closed smooth" "uzavretá hladká")
("closed spline" "uzavretý spline")
("closing" "ukončenie")
("closing style" "štýl záveru")
("cluster by affiliation" "zoskupiť podľa afiliácie")
("code" "zdrojový kód")
("collect garbage" "zbierať odpad (collect garbage)")
("collected keys" "zozbierané kľúče")
("color" "farba")
("color according to nesting level" "farba podľa úrovne vnorenia")
("color of the axes" "farba osí")
("color of the subunits" "farba podjednotiek")
("color of the units" "farba jednotiek")
("colors" "farby")
("column" "stĺpec")
("column contains glued items" "stĺpec obsahuje zlepené položky")
("column separation" "oddelenie stĺpca")
("column to the left" "stĺpec vľavo")
("column to the right" "stĺpec vpravo")
("columns" "stĺpce")
("columns separation" "oddelenie stĺpcov")
("command" "príkaz")
("commit" "komit")
("commit file" "komitnúť súbor")
("common" "bežný")
("common formats" "bežné formáty")
("commutative diagram" "komutatívny diagram")
("compact" "zhusti")
("compact lists" "zhustiť zoznamy")
("compactification" "zhustenie")
("compactify" "zhustiť")
("compare" "porovnať")
("compare with" "porovnať s")
("compatibility with other formats" "kompatibility s inými formátmi")
("compile article" "kompilovať článok")
("compile book" "kompilovať knihu")
("compile buffer" "kompilovať zásobník (buffer)")
("compile project" "kompilovať projekt")
("complete bibliographic reference" "doplniť odkaz na položku literatúry")
("completion" "dopĺňanie")
("complex" "komplexné")
("complex actions" "komplexné úkony")
("compose" "komponovať")
("compound" "zložené")
("compress" "komprimovať")
("compress into toolbar" "komprimovať do panela nástrojov")
("compressed" "komprimované")
("conceal" "ukryť")
("concrete" "konkrétne")
("condensed" "zhustené")
("condition" "podmienka")
("conference" "konferencia")
("configuration" "konfigurácia")
("configure look and feel" "konfigurovať vzhľad a štýl ovládania")
("confirm collected public key deletion" "potvrdiť zmazanie zozbieraných verejných kľúčov")
("confirm database entry" "potvrdiť položku databázy")
("confirm entry" "potvrdiť položku")
("confirm public key deletion" "potvrdiť zmazanie verejného kľúča")
("confirm secret key deletion" "potvrdiť zmazanie privátneho kľúča")
("confirm selected database entries" "potvrdiť zvolené položky databázy")
("confirm selected entries" "potvrdiť zvolené položky")
("confirm wallet destruction" "potvrdiť zničenie peňaženky")
("conjecture" "domnienka")
("conjectures" "domnienky")
("conservative conversion between LaTeX and TeXmacs" "konzervatívna konverzia medzi LaTeXom a TeXmacsom")
("conservative conversion options" "možnosti konzervatívnej konverzie")
("consoles" "konzoly")
("constants" "konštanty")
("constellation" "konštelácia")
("contact" "kontakt")
("content" "obsah")
("content tag" "značka obsahu")
("context dependent icons" "kontextovo závislé ikony")
("contextual hints" "kontextové tipy")
("continuation of" "pokračovanie")
("continue" "pokračovať")
("continued fraction" "reťazový zlomok")
("contour" "krivka")
("contract logarithms" "skrátiť logaritmy")
("contribute" "priespieť")
("control flow" "ovládať tok")
("control the evaluation of expressions" "ovládanie evaluácie výrazov")
("convention" "konvencia")
("conventions" "konvencie")
("convert" "skonvertovať")
("converters" "konvertory")
("converters to other data formats" "konvertory do iných dátových formátov")
("convertible" "konvertovateľný")
("copy" "kopírovať")
("copy new objects to all frames" "kopírovať nové objekty do všetkých rámcov")
("copy new objects to previous frames" "kopírovať nové objekty do predchádzajúcich rámcov")
("copy new objects to subsequent frames" "kopírovať nové objekty do nasledujúcich rámcov")
("copy text" "kopírovať text")
("copy to" "kopírovať do")
("copy to all frames after" "kopírovať tdo všetkých nasledujúcich rámcov")
("copy to all frames before" "kopírovať do všetkých predchádzajúcich rámcov")
("copy to all other frames" "kopírovať do všetkých ostatných rámcov")
("copying" "kopírovanie")
("copyright" "autorské práva")
("cork charset with TeX catcode definition in preamble" "sada znakov cork s TeX-ovým 'catcode' v preambule")
("cork with catcodes" "cork s 'catcodes'")
("corollaries" "dôsledky")
("corollary" "dôsledok")
("correct" "opraviť")
("correct all" "opraviť všetko")
("correct formula" "opraviť vzorec")
("correct manually" "opraviť manuálne")
("correct mathematical formulas" "opraviť matematické vzorce")
("correct text" "opraviť text")
("correction" "oprava")
("cosine" "kosínus")
("could not load" "nepodarilo sa načítať")
("count characters" "spočítať znaky")
("count lines" "spočítať riadky")
("count words" "spočítať slová")
("course" "smer")
("create a new document" "vytvoriť nový dokument")
("create context macro" "vytvoriť kontextové makro")
("create link" "vytvoriť odkaz")
("create preamble" "vytvoriť preambulu")
("create remote account" "vytvoriť vzdialený účet")
("create remote directory" "vytvoriť vzdialený adresár (priečinok)")
("create remote file" "vytvoriť vzdialený súbor")
("create subprogram" "vytvoriť podprogram")
("create subsession" "vytvoriť subsession")
("create table macro" "vytvoriť tabuľkové makro")
("create web site" "vytvoriť webstránky")
("created new document" "nový dokument vytvorený")
("creating new account" "vytvára sa novú účet")
("creating technical pictures" "vytvára sa technický obrázok")
("croatian" "chorvátčina")
("crop" "orezať")
("crop marks" "orezať masky")
("cross" "prečiarknuť")
("crossed boxes" "zaškrtnuté štvorčeky")
("crossed circles" "zaškrtnuté krúžky")
("current graphical mode" "súčasný grafický režim")
("current user version" "súčasná užívateľská verzia")
("current version" "súčasná verzia")
("cursor" "kurzor")
("cursors" "kurzory")
("curve" "krivka")
("curve intersections" "priesečníky kriviek")
("curve points" "body krivky")
("custom colors" "prispôsobené farby")
("custom tab" "prispôsobený tabulátor")
("customizations" "prispôsobenia (kustomizácie)")
("customize macro" "prispôsobiť makro")
("customizing TeXmacs" "prispôsobenie TeXmacsu")
("customizing and extending the user interface" "prispôsobenie a rozšírenie užívateľského rozhrania")
("customizing the TeXmacs styles" "prispôsobenie štýlov TeXmacsu")
("custum tab" "prispôsobený tabulátor")
("cut" "vystrihnúť")
("cut text" "vystrihnúť text")
("cut to" "vystrihnúť do")
("cyan" "tyrkysová")
("cypriot" "cyperčina")
("cyrillic" "azbuka")
("cyrillic input method" "metóda zadávania vstupu v azbuke")
("cyrillic italic right" "kurzíva vpravo v azbuke")
("czech" "čeština")
("dancers" "tanečníci")
("danish" "dánčina")
("dark grey" "tmavosivá")
("dark-vador" "dark-vador")
("dash" "pomlčka")
("dashes" "pomlčky")
("data" "dáta")
("data conversion" "konverzia dát")
("data format" "dátový formát")
("database entry" "položka databázy")
("database tool" "databázový nástroj")
("database toolbar" "panel nástrojov pre databázy")
("date" "dátum")
("deactivate" "deaktivovať")
("deactivate once" "deaktivovať raz")
("deactivate table" "deaktivovať tabuľku")
("dead" "mŕtvy")
("debug" "ladiť (debug)")
("debugging console" "konzola ladenia (debugging console)")
("debugging tool" "nástroj ladenia (debugging tool)")
("december" "december")
("decimal comma" "desatinná čiarka")
("decimal dot" "desatinná bodka")
("decomposed" "rozložené (dekomponované)")
("decorate atoms" "dekorovať atómy")
("decorated" "ozdobné")
("decorated wood" "zdobené drevo")
("decorative" "dekoratívne")
("decrease size" "zmenšiť veľkosť")
("decrypt" "dešifrovať")
("decrypted" "dešifrované")
("decryption" "dešifrovanie")
("default" "štandardné")
("default padding" "štandardné odskoky")
("default size" "štandardná veľkosť")
("definition" "definícia")
("definitions" "definície")
("degrade" "degradovať")
("degraded" "degradovaný")
("delete" "odstrániť")
("delete column" "odstrániť stĺpec")
("delete documentation cache" "vymazať cache dokumentácie")
("delete entries" "vymazať položky")
("delete link" "vymazať odkaz")
("delete row" "odstrániť riadok")
("delete selected entries in wallet" "zmazať zvolené položky v peňaženke")
("delete user identity" "zmazať identitu užívateľa")
("deleted" "odstránené")
("denominator" "menovateľ")
("describe" "opíš")
("describe tag" "opíš značku")
("description" "popis")
("destination" "cieľ")
("destroy" "zničiť")
("detach" "odpojiť")
("detach master" "odpojiť hlavný (master)")
("detailed" "podrobný")
("detailed menus" "podrobné menu")
("details in menus" "detaily v menu")
("determinant" "determinant")
("determine margins from text width" "urči okraje zo šírky textu")
("devangari" "devangari")
("developer" "vývojár")
("developer tool" "vývojársky nástroj")
("developers guide" "návod pre vývojárov")
("device" "zariadenie")
("diamond" "diamant")
("differentiate" "rozlíšiť")
("digital" "digitálny")
("dilate" "roztiahnuť")
("direction of progression" "smer postupu")
("direction of translation" "smer prekladu")
("directory" "adresár (priečinok)")
("disable" "vypnúť")
("disable coloring on paper" "na papieri vypnúť zafarbenie")
("disable encryption" "vypnúť šifrovanie")
("disable first indentation" "vypnúť odsadzovanie prvého")
("disable first indentation after" "vypnúť odsadzovanie prvého za")
("disable first indentation before" "vypnúť odsadzovanie prvého pred")
("disable indentation" "vypnúť odsadzovanie")
("disable indentation after" "vypnúť odsadzovanie po")
("disable indentation before" "vypnúť odsadzovanie pred")
("disabled" "vypnuté")
("disallow" "nepovoliť")
("disappear" "zmiznúť")
("disk" "")
("display style" "štýl zobrazenia")
("displayed formula" "jednoriadkový vzorec")
("dissociate joined cells" "rozdeliť spojené bunky")
("distill encapsulated Pdf files" "destilovať zapuzdrené Pdf súbory")
("distort" "skresliť")
("distorted" "skreslené")
("distribute unused space" "rovnomerne rozložiť medzery")
("div" "podiel")
("division" "delenie")
("do not break up large formulas" "nerozdeľovať veľké vzorce")
("do not remap" "neremapovať")
("document" "dokument")
("document colors" "farby dokumentu")
("document font selector" "výber písma dokumentu")
("document format" "formát dokumentu")
("document language" "jazyk dokumentu")
("document metadata" "metadáta dokumentu")
("document page format" "formát strán dokumentu")
("document paragraph format" "formát odstavcov dokumentu")
("document source tree preferences" "preferencie stromu zdrojového kódu dokumentu")
("document style" "štýl dokumentu")
("document styles" "štýly dokumentu")
("document updates run" "")
("documentation" "dokumentácia")
("documents are trees" "dokumenty sú stromy")
("documents in separate windows" "dokumenty v samostatných oknách")
("dot" "bodka")
("dots" "bodky")
("double stroke" "dvakrát prečiarknutý")
("double the zoom factor for TeXmacs documents" "zdvojnásobiť faktor zväčšenia pre TeXmacsové dokumenty")
("down" "dolu")
("download" "stiahnuť")
("downwards" "smerom dolu")
("dpi" "dpi")
("dragging" "ťahanie")
("draw" "kresliť")
("draw graphics" "kresliť grafiku")
("draw image" "nakresliť obrázok")
("draw over" "nakresliť nad")
("draw over selection" "kresliť cez označené")
("draw under" "nakresliť pod")
("drop" "pustiť")
("due to" "kvôli")
("duplicate" "duplikovať")
("duplicate labels" "duplikovať popisky (labels)")
("duration" "trvanie")
("dutch" "holandčina")
("dynamic" "dynamické")
("dynamic libraries" "dynamické knižnice")
("eRROR" "cHYBA")
("echelon" "šík")
("edit" "upraviť")
("edit animation" "upraviť animáciu")
("edit groups of objects" "upraviť skupinu objektov")
("edit macro" "upraviť makro")
("edit macros" "upraviť makrá")
("edit object properties" "upraviť vlastnosti objektu")
("edit package" "upraviť balíček")
("edit preamble" "upraviť preambulu")
("edit source" "upraviť zdrojový kód")
("edit source tree" "upraviť zdrojový strom")
("edit style" "upraviť štýl")
("edit translations file" "upraviť súbor s prekladmi")
("editing tools" "editačné nástroje")
("education" "vzdelanie")
("effect pen" "efektové pero")
("eigenvalues" "vlastné hodnoty")
("eigenvalues and vectors" "vlastné hodnoty a vektory")
("eighth" "ôsmy")
("elevation" "zdvih")
("email" "email")
("embed all linked images" "vložiť (embedovať) všetky odkazované obrázky")
("embed image" "vložiť (embedovať) obrázok")
("embed this image" "vložiť (embedovať) tento obrázok")
("embold" "zvýrazniť hrubo")
("emboss" "embosovať")
("emphasize" "zvýrazniť")
("emphasize text" "zvýrazniť text")
("empty box" "prázdny box")
("enable first indentation" "zapnúť odsadzovanie prvého")
("enable first indentation after" "zapnúť odsadzovanie prvého za")
("enable first indentation before" "zapnúť odsadzovanie prvého pred")
("enable indentation" "zapnúť odsadzovanie")
("enable indentation after" "zapnúť odsadzovanie za")
("enable indentation before" "zapnúť odsadzovanie pred")
("enable page breaking" "zapnúť zalamovanie strán")
("enabled" "zapnuté")
("encl" "prílohy")
("encoding" "kódovanie znakov")
("encrypt" "zašifrovať")
("encrypted" "zašifrované")
("encrypted buffer" "zašifrovaný zásobník (buffer)")
("encryption" "šifrovanie")
("encryption error" "chyba šifrovania")
("encryption facilities are not currently available" "funkcionalita šifrovania nie je momentálne dostupná")
("encryption facilities have not been enabled for TeXmacs" "funkcionalita šifrovania nebola pre TeXmacs zapnutá")
("end" "koniec")
("enforce brackets to match" "vynucovať zhodu zátvoriek")
("english" "angličtina")
("engrave" "vyryť")
("enter a title" "zadať nadpis")
("enter data" "zadať dáta")
("enter graphic mode" "prepnúť do grafického módu")
("enter graphics" "povoliť grafiku")
("enter graphics mode" "prepnúť do režimu grafiky")
("enter new passphrase for encryption" "zatať nové heslo pre šifrovanie")
("enter passphrase for decryption" "zadať heslo pre dešifrovanie")
("enter passphrase for identity" "zadať heslo pre identitu")
("enter title information" "zadať náležitosti nadpisu")
("entire table" "celá tabuľka")
("entry" "položka")
("entry type" "typ položky")
("entry up to date in database" "položka v databáze aktuálna")
("enumerate" "číslovaný zoznam")
("enumerate|Alpha" "číslovanie|Abecedné")
("enumerate|Roman" "číslovanie|Rímske")
("enumerate|alpha" "číslovanie|abecedné")
("enumerate|roman" "číslovanie|rímske")
("enunciation" "výrok")
("env" "prostredie")
("environment" "prostredie")
("environment variable" "premenná prostredia")
("environments" "prostredia")
("epilogue" "epilóg")
("equal" "rovná sa")
("equation" "rovnica")
("equations" "rovnice")
("equivalent for" "ekvivalent pre")
("erode" "erodovať")
("error" "chyba")
("error messages" "chybová správa")
("error output" "výstup chyby")
("error status report" "správa o stave chyby")
("error: bracket does not match" "chyba: zátvorka sa nezhoduje")
("error: cyclic or missing chunks detected" "chyba: boli detekované cyklické alebo chýbajúse kusy")
("error: file not found" "chyba: súbor nenájdený")
("error: ghostview does not seem to be installed on your system" "chyba: Zdá sa, že program ghostview nie je vo vašom systéme nainštalovaný")
("error: one of the alternatives should be filled out" "chyba: mala by byť vyplnená jedna z alternatív")
("error: only one alternatives should be filled out" "chyba: mala by byť vyplnená iba jedna alternatíva")
("error: should fill out name for referencing" "chyba: malo by sa vyplniť meno pre odkazovanie")
("error: should fill out required field" "chyba: malo by sa vyplniť požadované pole")
("escape" "escape")
("esperanto" "esperanto")
("etruscan" "etrusčina")
("evaluate" "vyhodnotiť")
("evaluate above" "vyhodnotiť nad")
("evaluate all" "vyhodnotiť všetko")
("evaluate below" "vyhodnotiť pod")
("evaluate fields" "vyhodnotiť polia")
("evaluate fields in order" "vyhodnotiť polia po poradí")
("evaluate scheme expression" "vyhodnotiť výraz scheme")
("evaluate script" "vyhodnotiť skript")
("evaluation" "vyhodnocovanie")
("evaluation switch" "prepínač evaluácie")
("evaluation tag" "značka evaluácie")
("even page" "párna strana")
("even page footer" "zápätie párnej strany")
("even page header" "hlavička párnej strany")
("even page left margin" "ľavý okraj párnej strany")
("even page margin" "okraj párnej strany")
("even page shift" "posunutie párnej strany")
("even page text" "text párnej strany")
("even pages" "párne strany")
("events" "udalosti")
("exact" "presné")
("exact horizontal" "presná vodorovná")
("exact mode" "presný režim")
("exam" "skúška")
("example" "príklad")
("examples" "príklady")
("exclusive" "jedinečné")
("exclusive or" "nerovnaké (XOR)")
("executable" "spustiteľný")
("execute" "spustiť")
("execute a TeXmacs command" "vykonať príkaz TeXmacsu")
("execute system command" "vykonať systémový príkaz")
("execution of scripts" "vykonávanie skriptov")
("executive" "exekutívny")
("exercise" "cvičenie")
("exercises" "cvičenia")
("exit graphics" "vyjsť z grafiky")
("exit graphics mode" "vyjsť z grafického režimu")
("exit left" "vyjsť vľavo")
("exit right" "vyjsť vpravo")
("exit tag on the left" "vyjsť zo značky doľava")
("exit tag on the right" "vyjsť zo značky doprava")
("expand" "expandovať")
("expand TeXmacs macros with no LaTeX equivalents" "expandovať TeXmacsové makrá, ktoré nemajú LaTeXové ekvivalenty")
("expand beamer slides" "expandovať obrazovky prezentácie (beamer slides)")
("expand inclusions" "expandovať inklúzie")
("expand logarithms" "expandovať logaritmus")
("expand trigonometric functions" "expandovať trigonometrické funkcie")
("expand unrecognized macros" "expandovať nerozoznané makrá")
("expand user-defined macros" "expandovať užívateľsky definované makrá")
("expanded" "expandované")
("experimental" "experimentálne")
("experimental features (to be used with care)" "experimentálna funkcionalita (treba používať opatrne)")
("explain" "vysvetliť")
("explained" "vysvetlené")
("explanatory item" "vysvetľujúca položka")
("explicit keystroke" "explicitný úder klávesu")
("explicit margins" "explicitné okraje")
("exponential" "exponenciála")
("exponential functions" "exponenciálne funkcie")
("export" "export")
("export as" "exportovať ako")
("export bibliographies as links" "exportovať zoznamy literatúry ako odkazy")
("export bibliography" "exportovať zoznam literatúry")
("export entries in buffer" "exportovať položky zásobníku (bufferu)")
("export file" "exportovať súbor")
("export formulas as images" "exportovať vzorce ako obrázky")
("export mathematical formulas as MathJax" "exportovať matematické vzorce ako MathJax")
("export mathematical formulas as MathML" "exportovať matematické vzorce ako MathML")
("export mathematical formulas as images" "exportovať matematické vzorce ako obrázky")
("export selected entries" "exportovať označené položky")
("export selection" "exportovať označené")
("export selection as image" "exportovať označené ako obrázok")
("export selections as" "eportovať označené výbery ako")
("export sessions" "exportovať sedenia (sessions)")
("exported bibliographic entries" "exportovať položky literatúry")
("exported bibliographic references" "exportovať odkazy literatúry (bibliografické referencie)")
("extend" "rozšíriť (roztiahnuť)")
("extend or normal" "roztiahnuté alebo normálne")
("extend table to full paragraph width" "roztiahnuť tabuľku na celú šírku odstavca")
("extended" "roztiahnuté")
("extensible left arrow" "roztiahnuteľná ľavá šírka")
("extensible right arrow" "roztiahnuteľná pravá šípka")
("extern " "externé")
("external" "externé")
("extra" "navyše")
("extra branch" "vetva navyše")
("extra interline space" "dodatočný medziriadkový priestor")
("extra name" "ďalší názov")
("extract" "extrahovať")
("extract format" "extrahuj formát")
("extract style file" "extrahuj súbor so štýlom")
("extract style package" "extrahuj balíček so štýlom")
("factor" "deliteľ")
("fade" "vyblednúť")
("fade in" "postupne sa objaviť (fade in)")
("fade out" "postupne zmiznúť (fade out)")
("family" "rodina")
("fast" "rýchlo")
("fast decrease" "rýchle zníženie")
("fast environments" "rýchle prostredia")
("fast increase" "rýchle zvýšenie")
("february" "február")
("field reference" "odkaz na pole")
("fifth" "piaty")
("figure" "obrázok")
("figures" "obrázky")
("file" "súbor")
("file name" "meno súboru")
("file not found" "súbor sa nenašiel")
("file saved" "súbor uložený")
("fill color" "farba výplne")
("fill out" "vyplniť")
("filter" "filter")
("find file" "nájsť súbor")
("find next match" "nájsť ďalšiu zhodu")
("find text" "nájsť text")
("finished collecting symbols documentation" "zbieranie dokumentácie symbolov ukončené")
("finnish" "dokončiť")
("first" "prvý")
("first chunk" "prvý kus")
("first contact" "prvý kontakt")
("first difference" "prvý rozdiel")
("first error" "prvá chyba")
("first field" "prvé pole")
("first indentation" "prvé odsadenie")
("first item" "prvá položka")
("first occurrence" "výskyt")
("first page" "prvá strana")
("first similar" "prvé podobné")
("first start" "začať od")
("fit" "napasovať")
("fit to height" "napasovať na výšku")
("fit to screen" "napasovať na obrazovku")
("fit to screen width" "napasovať na šírku obrazovky")
("fit to width" "napasovať na šírku")
("five columns" "päť stĺpcov")
("fix broken citations" "opraviť nefunkčné citácie")
("fix broken references" "opraviť nefunkčné referencie")
("fix duplicate labels" "opraviť duplicitné nálepky (návestia)")
("fixed" "fixné (opravené?)")
("flag is off" "príznak (flag) je vypnutý")
("flag is on" "príznak (flag) je zapnutý")
("flat" "ploché")
("flatten" "sploštiť")
("flexibility" "flexibilita")
("flexibility factor for vertical spacing" "činiteľ flexibility pre zvislé medzery")
("floating algorithm" "plávajúci algoritmus")
("floating figure" "plávajúci obrázok")
("floating object" "plávajúci objekt")
("floating phantom" "plávajúci fantóm")
("floating table" "plávajúca tabuľka")
("focus" "fokus")
("focus dependent icons" "ikony závislé na fokuse")
("fold" "zbaľovanie")
("fold all" "zbaliť všetko")
("fold all fields" "zbaliť všetky polia")
("fold back" "zbaliť späť")
("fold input field" "zbaliť vstupné pole")
("folded" "zbalené")
("follow external links" "nasledovať externé odkazy")
("follow inverse links" "nasledovať inverzné odkazy")
("font" "písmo")
("font base size" "základná veľkosť písma")
("font customization" "prispôsobenie písma")
("font dpi" "dpi písma")
("font effects" "efekty písma")
("font family" "rodina písma")
("font name" "názov písma")
("font selector" "výber písma")
("font series" "séria písma")
("font shape" "tvar písma")
("font size" "veľkosť písma")
("font type" "typ písma")
("font variant" "variant písma")
("fonts" "písma")
("footer" "zápätie")
("footnote" "poznámka pod čiarou")
("for" "pre")
("for all" "pre  všetky")
("for each" "pre každý")
("force reloading of translations" "vynútiť znovunačítanie prekladov")
("foreground" "popredie")
("foreign" "cudzí")
("format" "formát")
("formatted and structured output" "formátovaný a štruktúrovaný výstup")
("formatted date" "formátovaný dátum")
("formatting" "formátovanie")
("formula" "vzorec") 
("formula style" "štýl vzorca")
("forward" "vpred")
("forward replace" "nahradzovať smerom vpred")
("forward search" "vyhľadať smerom vpred")
("four columns" "štyri stĺpce")
("four dots" "štyri bodky")
("fourth" "štvrtý")
("fraction" "zlomok")
("fraktur" "fraktur")
("framed" "orámovaný")
("framed input fields" "orámované vstupné polia")
("framed programs" "orámované programy")
("framed theorems" "orámované teorémy")
("framed title" "orámovaný nadpis")
("french" "francúzština")
("frequency" "frekvencia")
("from" "od")
("from center" "zo stredu")
("front matter" "prvé strany")
("full" "úplný")
("full author list" "úplný zoznam autorov")
("full manuals" "úplné manuály")
("full name" "celé meno")
("full screen mode" "režim na celú obrazovku")
("function" "funkcia")
("functional" "funkčné")
("further customization" "ďalšie prispôsobenie")
("future changes" "budúce zmeny")
("gNU TeXmacs comes without any form of legal warranty" "na gNU TeXmacs sa nevzťahuje žiadna forma právnej záruky")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs spadá pod licenciu GNU GPL")
("gap" "medzera")
("garbage collection" "zbieranie odpadu (garbage collection)")
("gaussian" "gaussovský")
("gaussian blur" "gaussovské rozmazanie")
("gcd" "nsd")
("general" "všeobecný")
("general architecture of TeXmacs" "všeobecná architektúra TeXmacsu")
("general negation" "všeobecná negácia")
("general note" "všeobecná poznámka")
("generate GnuPG key" "generovať GnuPG kľúč")
("generated LaTeX document contains no errors" "generovaný LaTeXový dokument neobsahuje žiadne chyby")
("generated field" "")
("generating font file" "generuje sa súbor s prísmom")
("generic" "generický")
("generic input color" "generická farbs vstupu")
("generic prompt color" "generická farba výzvy")
("geometry" "geometria")
("georgian" "gruzínčina")
("german" "nemčina")
("get arity" "získať vzdušnosť")
("get label" "získať nálepku (návestie)")
("get list with remote versions" "získať zoznam vzdialených verzií")
("getting started" "začíname")
("global log" "log")
("global status" "globálny stav")
("glossary" "glosár")
("glossary entry" "položka glosára")
("glue" "zlepiť")
("glue decorations" "zlepiť dekorácie")
("glue multiple spaces" "zlepiť viacero medzier")
("glyphs" "piktogramy")
("gnaw" "obhrýzť")
("gnawed" "obhryzené")
("gnuPG command" "príkaz GnuPG")
("gnuPG decryption error" "dešifrovacia chyba GnuPG")
("gnuPG error: buffer encryption failed" "chyba GnuPG: šifrovanie zásobníka (bufferu) zlyhalo")
("gnuPG error: cannot find suitable secret key to decrypt" "chyba GnuPG: nepodarilo sa nájsť vhodný privátny kľúč na dešifrovanie")
("gnuPG requires name and email to have at least 5 characters" "gnuPG vyžaduje aby meno a email mali aspoň 5 znakov")
("go" "choď na")
("go to anchor" "choď na kotvu")
("go to anchor or float" "choď na kotvu alebo plávajúci objekt")
("go to anchor or footnote" "choď na kotvu alebo poznámku pod čiarou")
("go to first similar tag" "choď na prvú podobnú značku")
("go to float" "choď na plávajúci objekt")
("go to footnote" "choď na poznámku pod čiarou")
("go to last similar tag" "choď na poslednú podobnú značku")
("go to next similar tag" "choď na nasledujúcu podobnú značku")
("go to previous similar tag" "choď na predchádzajúcu podbnú značku")
("go to section" "choď na vyznačené")
("gothic" "gotický")
("gradient" "gradient")
("gradient selector" "voľba gradientu")
("grain" "zrno")
("granite" "žula")
("graphical effects" "grafické efekty")
("graphical interface" "grafické rozhranie")
("graphical interface font scale" "mierka písma grafického rozhrania")
("graphical overlays" "grafické priesvitky (overlays)")
("graphical slides and overlays" "grafické obrazovky prezentácie alebo priesvitky (overlays)")
("graphics" "grafika")
("graphics geometry" "geometria grafiky")
("graphics grids" "mriežky grafiky")
("grave" "obrátený dĺžeň")
("greater" "väčší")
("greater or equal" "väčší alebo rovný")
("greek" "gréčtina")
("greek letter" "grécke písmeno")
("green" "zelená")
("grey" "sivá")
("greyed" "zosivelý")
("grid" "mriežka")
("grid curves" "krivky mriežky")
("grid lines" "čiary mriežky")
("grid points" "body mriežky")
("grid-curve intersections" "priesečníky mriežkovej krivky")
("group" "skupina")
("group of objects" "skupina objektov")
("group/ungroup" "zoskupiť/odskupiť")
("group/ungroup objects" "zoskupiť/odskupiť objekty")
("grouped" "zoskupený")
("guarantee transparent source tracking" "garantovať transparentné sledovanie zdroja")
("h modifier" "modifikátor h")
("half wide" "polovičná šírka")
("hand drawn" "rukou kreslené")
("handwritten" "rukoupísané")
("hanging theorems" "visiace teorémy")
("hangul" "hangul")
("happy typing" "veselé písanie")
("has been aborted" "bolo prerušené")
("has completed its task" "dokončil svoju úlohu")
("hat" "strieška")
("header" "záhlavie (hlavička)")
("header and footer" "záhlavie (hlavička) a päta")
("header bars" "lišty hlavičky")
("headers" "hlavičky")
("hebrew" "hebrejčina")
("height" "výška")
("height is exactly the specified height" "výška je presne podľa zadania")
("height is maximum of specified height and box height" "výška je maximum zo zadanej výšky a výšky boxu")
("height is minimum of specified height and box height" "výška je minimum zo zadanej výšky a výšky boxu")
("height magnification" "zväčšenie výšky")
("help" "pomoc")
("help balloon" "bublina pomoci")
("help me" "pomôžte mi")
("help us" "pomôžte nám")
("here" "tu")
("hidden" "skrytý")
("high resolution screen settings" "nastavenia obrazovky s vysokým rozlíšením")
("high resolution settings" "nastavenia pre vysoké rozlíšenie")
("highlight errors" "zvýrazňovať chyby")
("history" "história")
("home" "domovský adresár")
("homepage" "domovská stránka")
("homoglyph substitutions" "substitúcie homoglyfov")
("horizontal" "vodorovná")
("horizontal alignment" "vodorovné zarovnávanie")
("horizontal cell alignment" "vodorovné zarovnávanie buniek")
("horizontal collapse distance" "vodorovná vzdialenosť zbalenia")
("horizontal ink separation" "vodorovné oddelenie farby")
("horizontal margins" "vodorovné okraje")
("horizontal padding" "vodorovné odskoky")
("horizontal part" "vodorovná časť")
("horizontal position" "vodorovná poloha")
("horizontal space" "vodorovná medzera")
("horizontal table alignment" "vodorovné zarovnávanie tabuľky")
("horizontally align cell to the base" "zarovnať bunku vodorovne podľa základne")
("horizontally center the cell" "vodorovne vycentrovať bunku")
("how much longer may pages become" "o koľko sa môžu stránky predĺžiť")
("how much shorter may pages become" "o koľko sa môžu stránky skrátiť")
("huge" "obrovský")
("hungarian" "maďarčina")
("hybrid command" "hybridný príkaz")
("hyperbolic functions" "hyperbolické funkcie")
("hyperlink" "hyperodkaz")
("hyphenate as" "deľ slová ako")
("hyphenation" "delenie slov")
("ice" "ľad")
("icelandic" "islandčina")
("icon" "ikona")
("identifier" "identifikátor")
("idle" "nečinný")
("if" "ak")
("if hyphenated" "ak sú slová delené")
("iff" "akk")
("ignore" "ignorovať")
("image" "obrázok")
("image links" "odkazy obrázkov")
("impact" "dopad")
("implementation" "implementácia")
("import" "import")
("import bibliography" "importovať zoznam literatúry")
("import database entry" "importovať položku databázy")
("import entries in buffer" "importovať položky v zásobníku (bufferi)")
("import entry" "importovať položku")
("import file" "importovať súbor")
("import font" "importovať písmo")
("import public keys from buffer" "importovať verejné kľúče zo zásobníku (buffer-u)")
("import selected database entries" "importovať vybraté položky databázy")
("import selected entries" "importovať vybraté položky")
("import selections as" "importovať označené ako")
("import sessions" "importovať sedenia (sessions)")
("import sophisticated objects as pictures" "importovať zložité objekty ako obrázky")
("imported bibliographic entries" "importované položky literatúry")
("improving the current implementation" "zlepšovanie súčasnej implementácie")
("in popup windows" "v popup oknách")
("inactive" "neaktívne")
("inanimated" "animované")
("inch" "palec")
("inches" "palce")
("include" "zahrnúť")
("include a document" "zahrnúť dokument")
("include file" "zahrnúť súbor")
("inclusion into TeXmacs" "zahrnutie do TeXmacsu")
("inclusions" "zahrnutia")
("incomplete entries found to be filled out" "našli sa neúplné položky na doplnenie")
("increase size" "zväčšiť veľkosť")
("indent" "odsadenie")
("indent paragraphs" "odsadiť odstavce")
("indentation" "odsadzovanie")
("indentation flag" "značka odsadenia")
("index" "register")
("index entry" "položka registra")
("index level" "úroveň registra")
("indication" "indikácia")
("inflate" "nafúknuť")
("informative flags" "informatívne značky")
("initialize" "inicializovať")
("initialize wallet" "inicializovať peňaženku")
("initials" "iniciály")
("ink here" "kresliť tu")
("ink in" "kresliť do")
("ink out" "kresliť mimo")
("inline" "v riadku")
("inline args" "parametre v riadku")
("inline arguments" "parametre v riadku")
("inline code" "v riadku")
("inline content" "obsah v riadku")
("inline formula" "vzorec v riadku")
("inline note" "poznámka v riadku")
("inner" "vnútorné")
("inner bottom" "vnútorný spodný")
("inner left" "vnútorný ľavý")
("inner right" "vnútorný pravý")
("inner top" "vnútorný horný")
("input" "vstup")
("input command" "príkaz vstupu")
("input field" "pole vstupu")
("input mode" "režim vstupu")
("input options" "možnosti vstupu")
("insert" "vložiť")
("insert Pr" "vložiť Pr")
("insert a TeXmacs symbol" "vložiť TeXmacs symbol")
("insert a big operator" "vložiť veľký operátor")
("insert a binary operation" "vložiť binárny operátor")
("insert a binary relation" "vložiť binárnu reláciu")
("insert a blackboard bold character" "vložiť blackboard hrubý znak")
("insert a bold calligraphic character" "vložiť hrubý kaligrafický znak")
("insert a bold character" "vložiť hrubý znak")
("insert a calligraphic character" "vložiť kaligrafický znak")
("insert a computer program" "vložiť počítačový program")
("insert a condition" "vložiť podmienku")
("insert a control flow instruction" "vložiť inštrukciu kontroly toku")
("insert a fraction" "vložiť zlomok")
("insert a fraktur character" "vložiť fraktur znak")
("insert a gap" "vložiť medzeru")
("insert a greek character" "vložiť grécky znak")
("insert a large left delimiter" "vložiť veľkú ľavú zátvorku")
("insert a large right delimiter" "vložiť veľkú pravú zátvorku")
("insert a large separator" "vložiť veľký oddeľovač")
("insert a left subscript" "vložiť ľavý dolný index (subskript)")
("insert a link" "vložiť odkaz")
("insert a list" "vložiť zoznam")
("insert a miscellaneous symbol" "vložiť iný symbol")
("insert a multiple choice" "vložiť výber viacerých alternatív")
("insert a negation" "vložiť negáciu")
("insert a new branch" "vložiť novú vetvu")
("insert a new entry" "vložiť novú položku")
("insert a new item" "vložiť novú položku")
("insert a note or a floating object" "vložiť poznámku alebo plávajúci objekt")
("insert a numerical operation" "vložiť číselnú operáciu")
("insert a personal macro" "vložiť osobné makro")
("insert a picture" "vložiť obrázok")
("insert a prominent piece of text" "vložiť prominentný kus textu")
("insert a question" "vložiť otázku")
("insert a root" "vložiť odmocninu")
("insert a script" "vložiť skript")
("insert a section block" "vložiť blok sekcie")
("insert a square root" "vložiť druhú odmocninu")
("insert a table" "vložiť tabuľku")
("insert a table or a matrix" "vložiť tabuľku alebo maticu")
("insert a textual operation" "vložiť textovú operáciu")
("insert a textual operator" "vložiť textový operátor")
("insert a wide symbol above" "vložiť široký symbol nad")
("insert a wide symbol below" "vložiť široký symbol pod")
("insert above" "vložiť nad")
("insert abstract" "vložiť abstrakt")
("insert an" "vložiť")
("insert an accent" "vložiť akcent")
("insert an answer" "vložiť odpoveď")
("insert an arrow" "vložiť šípku")
("insert an enunciation" "vložiť enunciáciu")
("insert an environment" "vložiť prostredie")
("insert an n" "vložiť n")
("insert an operation on tuples" "vložiť operáciu na n-ticiach")
("insert annotation" "vložť anotáciu")
("insert appendix" "vložiť dodatok")
("insert arccos" "vložiť arkuskosínus")
("insert arcs" "vložiť oblúky")
("insert arcsin" "vložiť arkussínus")
("insert arctan" "vložiť arkustangens")
("insert arg" "vložiť parameter")
("insert argument" "vložiť parameter")
("insert argument after" "vložiť parameter za")
("insert argument before" "vložiť parameter pred")
("insert author" "vložiť autora")
("insert automatically generated content" "vložiť automaticky generovaný obsah")
("insert below" "vložiť pod")
("insert bibliography" "vložiť zoznam literatúry")
("insert big contour integral" "vložiť veľký krivkový integrál")
("insert big coproduct" "vložiť veľký koprodukt")
("insert big direct sum" "vložiť veľký priamy súčet")
("insert big dotted point" "vložiť veľkú bodku v krúžku (dotted point)")
("insert big integral" "vložiť veľký integrál")
("insert big intersection" "vložiť veľký prienik")
("insert big logical and" "vložiť veľkú konjunkciu (logický and)")
("insert big logical or" "vložiť veľkú disjunkciu (logický or)")
("insert big product" "vložiť veľký súčin")
("insert big square union" "vložiť veľké hranaté zjednotenie")
("insert big summation" "vložiť veľký súčet")
("insert big tensor product" "vložiť veľký tenzorový súčin")
("insert big union" "vložiť veľké zjednotenie")
("insert big union sum" "vložiť veľký zjednocujúci súčet")
("insert big vertical space" "vložiť veľkú zvislú medzeru")
("insert chapter" "vložiť kapitolu")
("insert circles" "vložiť kruhy")
("insert closed splines" "vložiť uzavretý splajn")
("insert column" "vložiť stĺpec")
("insert column to the left" "vložiť stĺpec naľavo")
("insert column to the right" "vložiť stĺpec napravo")
("insert copyright and license information" "vložiť informáciu o autorských právach a licencii")
("insert cos" "vložiť kosínus")
("insert cosh" "vložiť hyporbolický kosínus")
("insert cot" "vložiť kotangens")
("insert coth" "vložiť hyperbolický kotangens")
("insert csc" "vložiť kosekans")
("insert deg" "vložiť deg")
("insert det" "vložiť det")
("insert dim" "vložiť dim")
("insert dollar" "vložiť dolár")
("insert equation" "vložiť rovnicu")
("insert executable markup" "vložiť spustiteľnú značku (markup)")
("insert exp" "vložiť exp")
("insert explanatory item" "vložiť vysvetľujúcu položku")
("insert field above" "vložiť pole nad")
("insert field below" "vložiť pole pod")
("insert fields" "vložiť polia")
("insert footnote" "vložiť poznámku pod čiarou")
("insert formula" "vložiť vzorec")
("insert gcd" "vložiť gcd")
("insert hand drawn curves" "vložiť ručne kreslené krivky")
("insert hom" "vložiť hom")
("insert horizontal interword space" "vložiť vodorovnú medzislovnú medzeru")
("insert image" "vložiť obrázok")
("insert inactive markup" "vložiť neaktívnku značku (markup)")
("insert inf" "vložiť inf")
("insert input field above" "vložiť vstupné pole nad")
("insert input field below" "vložiť vstupné pole pod")
("insert ker" "vložiť ker")
("insert left" "vložiť vľavo")
("insert lg" "vložiť lg")
("insert lim" "vložiť lim")
("insert liminf" "vložiť liminf")
("insert limsup" "vložiť limsup")
("insert lines" "vlžiť riadky")
("insert ln" "vložiť ln")
("insert log" "vložiť log")
("insert macro" "vložiť makro")
("insert mathematics" "vložť matematický výraz")
("insert max" "vložiť max")
("insert medium horizontal space" "vložiť stredne veľkú vodorovnú medzeru")
("insert medium vertical space" "vložiť stredne veľkú zvislú medzeru")
("insert min" "vložiť min")
("insert missing invisible operators" "vložiť chýbajúce neviditeľné operátory")
("insert more names" "vlažiť viac názvov")
("insert multiple paragraphs" "vložiť viacero odstavcov")
("insert negative horizontal space" "vložiť zápornú vodorovnú medzeru")
("insert new item or number" "vložiť novú položku alebo číslo")
("insert new rows or columns" "vložiť nové riadky alebo stĺpce")
("insert or delete rows or columns" "vložiť alebo odstrániť riadky alebo riadky")
("insert overlay after" "vložiť prekryvovú vrstvu za")
("insert overlay before" "vložiť prekryvovú vrstvu pred")
("insert particle" "vložiť časticu")
("insert plain text" "vložiť prostý text")
("insert points" "vložiť body")
("insert polygons" "vložiť mnohouholníky")
("insert right" "vložiť napravo")
("insert row" "vložiť riadok")
("insert row above" "vložiť riadok nad")
("insert row below" "vložiť riadok pod")
("insert sec" "vložiť sec")
("insert section" "vložiť sekciu")
("insert sharp" "vložiť symbol mriežky")
("insert similar above" "vložiť podobné nad")
("insert similar below" "vložiť podobné pod")
("insert similar block above" "vložiť podobný blok nad")
("insert similar block below" "vložiť podobný blok pod")
("insert sin" "vložiť sínus")
("insert sinh" "vložiť hyperbolický sínus")
("insert slide after" "vložiť stranu prezentácie (slide) za")
("insert slide before" "vložiť stranu prezentácie (slide) pred")
("insert small horizontal space" "vložiť malú vodorovnú medzeru")
("insert small vertical space" "vložiť malú zvislú medzeru")
("insert splines" "vložiť splajny")
("insert structural markup" "vložiť štrukturálnu značku (markup)")
("insert subscript" "vložiť dolý index (subskript)")
("insert subsection" "vložiť podsekciu")
("insert subsubsection" "vložiť podpodsekciu")
("insert sup" "vložiť sup")
("insert superscript" "vložiť horný index (superskript)")
("insert symbol documentation" "vložiť dokumentáciu symbolu")
("insert tan" "vložiť tangens")
("insert tanh" "vložiť hyperbolický tangens")
("insert template" "vložiť šablónu")
("insert text" "vložiť text")
("insert text field" "vložiť textové pole")
("insert text field above" "vložiť textové pole nad")
("insert text field below" "vložiť textové pole pod")
("insert thick horizontal space" "vložiť hrubú vodorovnú medzeru")
("insert title" "vložiť nadpis")
("insert title after name" "vložiť nadpis za meno")
("insert user interface related markup" "vložiť značku (markup) súvisiacu s užívateľských rozhraním")
("insert value" "vložiť hodnotu")
("inserting control points" "vložiť riadiace body")
("inside mathematics" "vnútri matematiky")
("integer arithmetic" "celočíselná aritmetika")
("integrate" "integrovať")
("interactive command" "interaktívny príkaz")
("interactive questions" "interaktívne otázky")
("intercharacter compression" "medziznakové stlačenie")
("intercharacter stretching" "medziznakové roztiahnutie")
("interfacing" "prepojenie")
("interfacing TeXmacs with other systems" "prepojenie TeXmacsu s inými systémami")
("interjection" "zvolanie")
("interline separation" "oddelenie riadkov")
("interline space" "medzera medzi riadkami")
("internationalization" "lokalizácia")
("interparagraph space" "medzera medzi odstavcami")
("interrupt execution" "prerušiť vykonávanie")
("interrupted" "prerušené")
("intersperse" "popretkávať (prekladať)")
("introduction" "úvod")
("invalid multi-paragraph selection" "neplatný viac-odstavcový výber")
("invalid paste of text into a formula" "neplatné vloženie textu do vzorca")
("invalid renaming" "neplatné premenovanie")
("invert" "invertovať")
("inverted breve" "obrátený oblý mäkčeň")
("invisible" "neviditeľný")
("invisible citation" "neviditeľná citácia")
("invisible ending" "neviditeľné ukončenie")
("invisible newline" "neviditeľný nový riadok")
("invisible opening" "neviditeľné otvorenie")
("inwards" "dovnútra")
("irish" "írčina")
("is running" "je spustený")
("is tuple" "je n-tica")
("ispell does not respond" "ispell nereaguje")
("ispell is already busy" "ispell už pracuje")
("italian" "taliančina")
("italic" "kurzíva")
("italic right" "kurzíva napravo")
("itemize" "nečíslovaný zoznam")
("january" "január")
("japanese" "japončina")
("join selected cells" "spojiť vybrané bunky")
("journal" "žurnál (časopis)")
("july" "júl")
("jump in" "skočiť do")
("june" "jún")
("junior" "junior")
("justify" "zarovnať")
("justified" "zarovnaný")
("justify text" "zarovnať text")
("keep evaluated expressions" "ponechať vyhodnotené výrazy")
("keep local" "ponechať lokálne")
("keep remote" "ponechať vzdialené")
("keep track of source code" "sledovať zdrojový kód")
("keep unfolded" "ponechať nezbalené")
("key" "kláves")
("key manager" "manager kľúčov")
("keyboard" "klávesnica")
("keyboard configuration" "konfigurácia klávesnice")
("keyboard equivalent" "klávesový ekvivalent")
("keyboard modifiers" "klávesové modifikátory")
("keyboard shortcut" "klávesová skratka")
("keymaps" "mapovanie klávesov")
("keys" "kľúče")
("keyword" "kľúčové slovo")
("keywords" "kľúčové slová")
("kill" "ukončiť (kill)")
("known bugs" "známe chyby")
("korean" "kórejčina")
("laTeX errors" "chyby LaTeXu")
("label" "popisok")
("landscape" "na šírku")
("language" "jazyk")
("laptop presentations" "počítačové prezentácie")
("large" "veľký")
("large brackets" "veľké zátvorky")
("large cells" "veľké bunky")
("large closing bracket" "veľká uzatváracia hranatá zátvorka")
("large delimiter" "veľká zátvorka")
("large displayed" "veľké jednoriadkové")
("large displayed fraction" "veľký jednoriadkový zlomok")
("large opening bracket" "veľká otváracia hranatá zátvorka")
("large separator" "veľký oddeľovač")
("large tables" "veľké tabuľky")
("last" "posledné")
("last check" "posledná kontrola")
("last difference" "posledný rozdiel")
("last error" "posledná chyba")
("last field" "posledné pole")
("last name" "posledný názov")
("last occurrence" "posledný výskyt")
("last page" "posledná strana")
("last similar" "posledné podobné")
("latex command" "príkaz programu latex")
("latin" "latinka")
("layout" "rozloženie")
("lcm" "lcm")
("left" "ľavý")
("left aligned" "zarovnané doľava")
("left arrow" "ľavá šípka")
("left axis" "ľavé na os")
("left baseline" "ľavé na učiarie (základná dotyčnica)")
("left border" "ľavé orámovanie")
("left bottom" "ľavé spodné")
("left cell border" "ľavé orámovanie bunky")
("left cell padding" "ľavý odskok bunky")
("left center" "ľavý stred")
("left click: add point; Right click: undo" "ľavý klik: pridať bod; Pravý klik: odčiniť")
("left click: finish; Right click: undo" "ľavý klik: ukončiť; Pravý klik: odčiniť")
("left click: new object" "ľavý klik: nový objekt")
("left click: operate" "ľavý klik: vykonávať operácie")
("left down" "vľavo dolu")
("left margin" "ľavý okraj")
("left on even pages" "vľavo na párnych stranách")
("left padding" "ľavý odskok")
("left prime" "ľavá čiarka (apostrof)")
("left slanted" "sklonené doľava")
("left subscript" "ľavý dolný index (subskript)")
("left superscript" "ľavý horný index (superskript)")
("left surrounding" "ľavé okolie")
("left table border" "ľavé orámovanie tabuľky")
("left table padding" "ľavý odskok tabuľky")
("left top" "vľavo navrchu")
("left up" "vľavo hore")
("left-right arrow" "šípka doľava-doprava")
("leftwards" "doľava")
("legal" "legal")
("lemma" "lemma")
("lemmas" "lemmy")
("length" "dĺžka")
("less" "menšie")
("less or equal" "menšie alebo rovné")
("let the environment float" "nechať prostredie plávať")
("letter" "list")
("license" "licencia")
("light" "jemné")
("light grey" "svetlá sivá")
("limit" "limita")
("limitations" "obmedzenia")
("limits" "limity")
("line" "riadok")
("line break" "zalomenie riadku")
("line breaking" "zalamovanie riadkov")
("line count" "počet riadkov")
("line dashes" "čiarkované čiary")
("line portion" "pomer riadkov")
("line stretch" "roztiahnutie riadkov")
("line style" "štýl riadkov")
("line width" "šírka riadkov")
("line wrapping" "zalamovanie riadkov")
("line wrapping inside cell" "zalamovanie riadkov vo vnútri buniek")
("linear 2D" "lineárne 2D")
("linear algebra" "lineárna algebra")
("lines around" "čiary nad a pod")
("link" "odkaz")
("link all embedded images" "prepojiť všetky embedované obrázky")
("link image" "odkaz na obrázok")
("link image and copies as" "prepojiť obrázok a kópie ako")
("link image as" "prepojiť obrázok ako")
("link mode" "režim odkazov")
("link to URL" "odkaz na URL")
("linking tool" "linkovací nástroj")
("lissajous" "lissajousove")
("list" "zoznam")
("list of figures" "zoznam obrázkov")
("list of tables" "zoznam tabuliek")
("live" "živý")
("live input-output" "živý vstup-výstup")
("load" "otvoriť")
("load LaTeX file" "načítať súbor LaTeX")
("load TeX file" "načítať súbor TeX")
("load TeXmacs file" "otvoriť súbor TeXmacs")
("load TeXmacs style file" "otvoriť súbor so štýlom TeXmacs")
("load a file" "otvoriť súbor")
("load buffer" "načítať zásobník (buffer)")
("load file" "otvoriť súbor")
("load help file" "načítať súbor s pomocou")
("load html file" "načítať súbor html")
("load image" "načítať obrázok")
("load in new window" "otvoriť v novom okne")
("load latex file" "načítať súbor latex")
("load more recent autosave file" "načítať novší automaticky uložený súbor")
("load remote file" "načítať vzdialený súbor")
("load tex file" "načítať súbor tex")
("load verbatim file" "načítať súbor verbatim")
("loaded" "načítaný")
("loading" "načítava sa")
("local entries" "lokálne položky")
("loci" "miesta (loci)")
("locus" "miesto (locus)")
("locus color" "farba miesta (locus-u)")
("locus rendering" "vykresľovanie miesta (locus-u)")
("logarithm" "logaritmus")
("logarithmic" "logaritmické")
("logarithmic base" "základ logaritmu")
("logarithms" "logaritmy")
("logging in" "priehlásenie sa")
("logical and" "konjunkcia (logický 'and')")
("logical implication" "logická impikácia")
("logical not" "negácia (logický 'not')")
("logical or" "disjunkcia (logický 'or')")
("login" "prihlásenie")
("logout" "odhlásenie")
("long" "dlhý")
("long macro" "dlhé makro")
("long text" "dlhý text")
("look and feel" "vzhľad a štýl ovládania")
("look for more fonts" "vyhľadať ďalšie písma")
("look up" "vyhľadať")
("loops" "cykly")
("lower border" "spodné orámovanie")
("m modifier" "modifikátor m")
("macro" "makro")
("macro argument" "parameter makra")
("macro definition" "definícia makra")
("macro editor" "editor makier")
("macro name" "názov makra")
("macros" "makrá")
("macros editor" "editor makier")
("magenta" "fialová")
("magic" "kúzelný")
("magnification" "zväčšenie")
("magnified" "zväčšené")
("magnify horizontally" "zväčšiť vodorovne")
("magnify vertically" "zväčšiť zvislo")
("main" "hlavný")
("main document font" "hlavné písmo dokumentu")
("main document style" "hlavný štýl dokumentu")
("main icon bar" "hlavný panel nástrojov")
("main presentation style" "hlavný štýl prezentácie")
("major changes" "hlavné zmeny")
("make a letter environment" "previesť na prostredie 'list'")
("make a multi-slide presentation" "previesť na viac-stranovú prezentáciu")
("make a page insertion" "vloženie strany")
("make a subscript" "previesť na dolný index")
("make a superscript" "previesť na horný index")
("make acute" "pridať dĺžeň")
("make bar" "pridať pruh")
("make block wide" "previesť blok na široký")
("make check" "pridať mäkčeň")
("make float wide" "previesť plávajúci objekt na široký")
("make floating" "prieviesť na plávajúci objekt")
("make footnote wide" "previesť poznámku pod čiarou na širokú")
("make fraction" "zlomok")
("make grave" "pridať obrátený dĺžeň")
("make hat" "pridať striešku")
("make label" "vytvoriť nálepku (label)")
("make link" "vytvoriť odkaz")
("make negation" "urobiť negáciu")
("make non floating" "previesť na neplávajúci objekt")
("make opaque" "zneprehliadniť")
("make page reference" "vložiť odkaz na stranu")
("make reference" "vložiť odkaz")
("make slides" "spraviť prezentáciu")
("make square root" "vložiť druhú odmocninu")
("make tilde" "pridať vlnku (tildu)")
("make title" "vytvoriť nadpis")
("make transparent" "spriehľadniť")
("make vector" "pridať znak vektora")
("make wide" "zmeniť na široké")
("making donations" "ako finančne podporiť")
("manila paper" "manilský (baliaci) papier")
("manila-paper" "baliacopapierový")
("manual" "manuál")
("manual path" "manuálna cesta")
("map arguments" "priradiť parametre (parametre zobrazenia?)")
("map to" "priraď k")
("march" "marec")
("marginal note" "poznámka za okrajom")
("margins" "okraje")
("margins as on paper" "okraje ako na papieri")
("margins from width" "okraje zo šírky")
("margins on paper" "okraje na papieri")
("margins on screen" "okraje na obrazovke")
("marked" "označené")
("marker" "fixka")
("master" "hlavný")
("master file" "hlavný súbor")
("material" "materiál")
("math" "matematika")
("math Extra" "matematika Extra")
("math Letters" "matematika Písmená")
("math Symbols" "matematika Symboly")
("math font" "písmo pre matematiku")
("math font family" "rodina písma pre matematiku")
("math font series" "séria písma pre matematiku")
("math font shape" "tvar písma pre matematiku")
("mathematical" "matematický")
("mathematical and customized input" "matematický a kustomizovaný vstup")
("mathematical font" "matematické písmo")
("mathematical formulas" "matematické vzorce")
("mathematical input" "matematický vstup")
("mathematical output" "matematický výstup")
("mathematical typesetting" "matematická sadzba")
("mathematics" "matematika")
("matrices" "matice")
("matrix" "matica")
("matrix factorization" "faktorizácia matíc")
("maximal" "maximálny")
("maximal cell height" "maximálna výška bunky")
("maximal clustering" "maximálne zoskupovanie")
("maximal number of columns" "maximálny počet stĺpcov")
("maximal number of rows" "maximálny počet riadkov")
("maximal table height" "maximálna výška tabuľky")
("maximal table width" "maximálna šírka tabuľky")
("maximum" "maximum")
("maximum mode" "maximálny režim")
("may" "máj")
("meander" "kľukatiť sa")
("medieval" "stredoveký")
("medium" "stredný")
("medium skip" "sdredný odstup")
("meminfo" "informácie o pamäti")
("memory" "pamäť")
("memory usage" "využitie pamäte")
("menu" "menu")
("merge" "zlúčiť")
("merge lines into paragraphs unless separated by blank lines" "zlúčiť riadky do odstavca ak nie sú oddelené prázdnymi riadkami")
("messages" "správy")
("messy" "chaotické")
("meta key" "kláves meta")
("meta data" "metadáta")
("metal" "kov")
("middle" "stredný")
("minimal" "minimálny")
("minimal cell height" "minimálna výška bunky")
("minimal cell width" "minimálna šírka bunky")
("minimal line separation" "minimálny rozostup riadkov")
("minimal number of columns" "minimálny počet stĺpcov")
("minimal number of rows" "minimálny počet riadkov")
("minimal table height" "minimálna výška tabuľky")
("minimal table width" "minimálny šírka tabuľky")
("minimum" "minimum")
("minimum mode" "minimálny režim")
("minus" "mínus")
("mirror" "zrkadliť")
("miscellaneous" "rôzne")
("miscellaneous features" "rôzne funkcie")
("miscellanous" "rôzne")
("mixed" "zmiešané")
("mod" "modulo")
("mode" "režim")
("mode dependent icons" "ikony špecifické pre režim")
("modifier" "modifikátor")
("modify bibliography" "zmeniť literatúru")
("modify cell alignment" "zmeniť zarovnanie bunky")
("modify cell border" "zmeniť orámovanie bunky")
("modify cell padding" "zmeniť odskok bunky")
("modify cell size" "zmeniť veľkosť bunky")
("modify remote live document" "zmeniť vzdialený živý dokument")
("modify table border" "zmeniť orámovanie tabuľky")
("modify table padding" "zmeniť rozostup buniek tabuľky")
("module" "module")
("module browser" "prehliadač modulov")
("mongolian" "mongolčina")
("monospaced" "s rovnakými medzerami medzi znakmi")
("month" "mesiac")
("more information about GNU TeXmacs can be found in the Help" "viac informácií o GNU TeXmacs-e je možné nájsť v Pomoci")
("more information about GNU TeXmacs can be found in the Help->About menu" "viac informácií o GNU TeXmacs-e je možné nájsť v menu Pomoc->O TeXmacse")
("more information about GNU TeXmacs can be found in the help" "viac informácií o TeXmacs-e je možné nájsť v pomoc-i")
("mosaic" "mozaika")
("motion" "pohyb")
("motion blur" "pohybové rozmazanie")
("mouse over balloon" "bublina 'mouse over'")
("mouse over object" "objekt 'mouse over'")
("move" "presunúť")
("move down" "presunúť nadol")
("move object" "presunúť objekt")
("move objects" "presunúť objekty")
("move over object on which to operate" "presunúť objekt s ktorým sa má pracovať")
("move to the right when finished" "po ukončení presunúť napravo")
("move up" "presunúť hore")
("move::difference" "")
("move::similar" "")
("multiline" "viacriadkový")
("multiline input" "viacriadkový vstup")
("multiple choice" "výber viacerých alternatív")
("multiple documents share window" "viaceré dokumenty zdieľajú okno")
("multiple root" "viacnásobný koreň")
("multiplication" "násobenie")
("mutator tags" "mutátorové značky")
("my bibliographic database" "moja databáza literatúry")
("my documents" "moje dokumenty")
("n-th" "n-tý")
("n-th root" "n-tá odmocnina")
("name" "názov")
("name of bibliography" "názov literatúry")
("name of glossary" "názov glosára")
("name of index" "názov registra")
("name of list of figures" "názov zoznamu obrázkov")
("name of list of tables" "názov zoznamu tabuliek")
("name of table of contents" "názov obsahu")
("named" "pomenované")
("navigation options" "možnosti navigácie")
("negation" "negácia")
("never" "nikdy")
("new" "nový")
("new account" "nový účet")
("new bibliography dialogue" "nový dialóg literatúry")
("new buffer" "nový zásobník (buffer)")
("new column" "nový stĺpec")
("new context macro" "nové kontextové makro")
("new document" "nový dokument")
("new double page" "nový dvojstrana")
("new double page before" "nová dvojstrana pred")
("new entry" "nová položka")
("new identity" "nová identita")
("new item" "nová položoka")
("new line" "nový riadok")
("new locus" "nové miesto (locus)")
("new macro" "nové makro")
("new number" "nové číslo")
("new page" "nová strana")
("new page before" "nová strana pred")
("new paragraph" "nový odstavec")
("new passphrase" "heslo")
("new remote directory" "nový vzdialený adresár (priečinok)")
("new remote file" "nový vzdialený súbor")
("new roman" "new roman")
("new row" "nový riadok")
("new style fonts" "nové písma štýlu")
("new style page breaking" "nové zalamovani strán štýlu")
("new table" "nová tabuľka")
("new table macro" "nové makro tabuľky")
("new version" "nová verzia")
("new window" "nové okno")
("newer version" "novšia verzia")
("next" "nasledujúci")
("next chunk" "nasledujúci kus")
("next difference" "nasledujúci rozdiel")
("next error" "nasledujúca chyba")
("next field" "nasledujúce pole")
("next line" "nasledujúci riadok")
("next occurrence" "nasledujúci výskyt")
("next screen" "nasledujúca obrazovka")
("next similar" "nasledujúci podobný")
("no" "nie")
("no animation" "žiadna animácia")
("no changes need to be saved" "žiadne zmeny na uloženie")
("no clustering" "žiadne zoskupovanie")
("no completions" "žiadne dopĺňanie")
("no dictionary for" "neexistuje slovník pre")
("no errors have been corrected" "neboli opravené žiadne chyby")
("no first indentation" "neodsadzovať prvé")
("no grid" "žiadna mriežka")
("no indentation" "neodsadzovať")
("no line break" "nezalamovať riadok")
("no matches found" "nenašli sa žiadne zhody")
("no matches found for" "nenašli sa žiadne zhody pre")
("no more matches for" "nenašli sa žiadne ďalšie zhody pre")
("no more redo information available" "nie je k dispozícii žiadna ďalšia informácia pre akciu 'znovu vykonať'")
("no more undo information available" "nie je k dispozícii žiadna ďalšia informácia pre akciu 'odčiniť'")
("no multiple spaces" "žiadne viacnásobné medzery")
("no name" "bez názvu")
("no new public key in document" "žiadny verejný kľuč v dokumente")
("no page break" "nezalamovať stranu")
("no page break after" "nezalamovať stranu za")
("no page break before" "nezalamovať stranu pred")
("no page numbers" "bez čísiel strán")
("no parent" "žiadny rodič")
("no selection" "žiadny výber")
("no spelling errors" "žiadne pravopisné chyby")
("no spelling errors found in text" "v texte sa nenašli pravopisné chyby")
("no spurious spaces" "žiadne falošné medzery")
("no style" "žiadny štýl")
("none" "žiadny")
("normal" "normálny")
("normal loci" "normálne miesta (loci)")
("normal size" "normálna veľkosť")
("norwegian" "nórčina")
("not" "nie")
("not allowed to remove home directory" "nedovolené odstrániť domovský adresár (priečinok)")
("not connected to server" "nepripojené k serveru")
("not equal" "nerovná sa")
("not found" "nenájdené")
("not yet implemented" "ešte neimplementované")
("notation" "notácia")
("notations" "notácie")
("note" "poznámka")
("notebook" "poznámkový blok")
("notes" "poznámky")
("november" "november")
("number" "číslo")
("number equation" "číslovať rovnicu")
("number of columns" "počet stĺpcov")
("number of polar steps" "počet polárnych krokov")
("number of subunit steps" "počet podjednotkových krokov")
("numbered" "číslované")
("numbered equation" "číslovaná rovnica")
("numbered equations" "číslované rovnice")
("numbering" "číslovanie")
("numerator" "čitateľ")
("numeric" "číselné")
("numeric analysis" "číselná analýzy")
("numeric comma table" "číselná tabuľka s čiarkami")
("numeric dot table" "číselná tabuľka s bodkami")
("numeric spreadsheet" "číselná výpočtová tabuľka (spreadsheet)")
("objectives" "ciele")
("oblique" "šikmý")
("occurrences" "výskyty/ov")
("october" "október")
("odd page" "nepárna strana")
("odd page footer" "päta nepárnej strany")
("odd page header" "hlavička nepárnej strany")
("odd page left margin" "ľavý okraj nepárnej strany")
("odd page margin" "okraj nepárnej strany")
("odd page right margin" "pravý okraj nepárnej strany")
("odd page shift" "posun nepárnej strany")
("odd page text" "text nepárnej strany")
("odd pages" "nepárne strany")
("of fingerprint" "z odtlačku prsta")
("off" "vypnuté")
("ok" "ok")
("old english" "staroanglický")
("old slavonic" "staroslovanský")
("old style" "starý štýl")
("old version" "stará verzia")
("older version" "staršia verzia")
("on" "zapnuté")
("on cells" "na bunky")
("on columns" "na stĺpce")
("on entire table" "na celú tabuľku")
("on rows" "na riadky")
("on the footer" "na päte")
("on your system and set it up from the \"Security\" tab" "vo vašom systéme a nastavte ho v karte \"Bezpečnosť\"")
("once" "raz")
("one column" "jeden stĺpec")
("one error has been corrected" "bola opravená jedna chyba")
("one lower case letter, one non alpha-numeric symbol" "jedno malé písmeno, jeden alfa-numerický znak")
("one numeric character, one upper case letter" "jeden číselný znak, jedno veľké písmeno")
("one spelling error has been corrected" "bola opravená jedna pravopisná chyba")
("online documentation" "online dokumentácia")
("online help" "online pomoc")
("only convert changes when re-importing" "konvertovať zmeny iba pri re-importe")
("only convert changes with respect to imported version" "konvertovať iba zmeny voči importovanej verzii")
("only convert changes with respect to tracked version" "konvertovať iba zmeny voči sledovanej verzii")
("only implemented for complete subtrees" "implementované iba pre úplné podstromy")
("only inline tags" "iba značky v rámci riadku")
("only keep folded" "ponechať iba zbalené")
("only keep unfolded" "ponechať iba rozbalené")
("only show paragraphs with hits" "zobrazovať iba odstavce so zhodami")
("only show semantic focus" "zobrazovať iba semantický fokus")
("opacity" "nepriehľadnosť")
("open" "otvoriť")
("open a new buffer" "otvoriť nový zásobník (buffer)")
("open bibliography" "otvoriť literatúru")
("open identities" "otvoriť identity")
("open in new window" "otvoriť v novom okne")
("open key manager" "otvoriť správcu kľúčov")
("open licence agreement" "otvoriť licenčnú zmluvu")
("open mailbox" "otvoriť poštovú schránku")
("open module browser" "otvoriť prehliadač modulov")
("open new window" "otvoriť nové okno")
("open on errors" "otvoriť pri chybách")
("open on warnings" "otvoriť pri varovaniach")
("open symbol browser" "otvoriť prehliadač znakov")
("open tool in separate window" "otvoriť nástroj v separátnom okne")
("opening" "otvára sa")
("operation mode" "režim fungovania")
("operation on named selection" "operácia na pomenovanej označenej oblasti")
("operation on primary selection" "operácia na primárnej označenej oblasti")
("operation on secondary selection" "operácia na sekundárnej označenej oblasti")
("operation on ternary selection" "operácia na terciálnej označenej oblasti")
("optical" "optický")
("option" "možnosť")
("options" "možnosti")
("or" "alebo")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "alebo zadajte úplnú cestu k príkazu \"gpg\" alebo \"gpg2\"")
("orange" "oranžová")
("order" "usporiadať")
("ordinary symbol" "bežný znak")
("orientation" "orientácia")
("origin" "počiatok")
("original welcome message" "pôvodná uvítacia správa")
("ornamented" "s ornamentami")
("other" "iné")
("other login" "iné prihlasovacie meno")
("other package" "iný balíček")
("other pages" "iné strany")
("other projects" "iné projekty")
("other style" "iný štýl")
("outer" "vonkajšie")
("outer bottom" "vonkajšie spodné")
("outer left" "vonkajšie ľavé")
("outer right" "vonkajšie pravé")
("outer top" "vonkajšie horné")
("outline" "obrys")
("outlined" "obrysový")
("outlined emboss" "obrysový embosovaný")
("outlined engrave" "obrysový gravírovaný")
("outlined roman" "obrysový roman")
("output" "výstup")
("output options" "možnosti výstupu")
("outwards" "smerom von")
("oval" "oválne")
("oval blur" "oválne rozmazanie")
("over" "nad")
("overbrace" "horná svorka")
("overlap" "prekryv")
("overlay" "prekryvový vrstva")
("overlay mode" "režim prekrytia")
("overlays" "prekryvové vrstvy")
("overline" "prečiarknutie")
("overlined" "prečiarknuté")
("overview of the scheme extension language" "prehľad scheme - jazyka pre rozšírenia")
("padded" "s odskokom")
("padding" "odskakovanie")
("padding above" "odskok nad")
("padding below" "odskok pod")
("page" "strana")
("page background" "pozadie strany")
("page bottom margin" "spodný okraj strany")
("page break" "zalomenie strany")
("page break after" "zalomenie strany za")
("page break before" "zalomenie strany pred")
("page breaking algorithm" "algoritmus zalamovania strán")
("page format" "formát strany")
("page height" "výška strany")
("page insertion" "vloženie strany")
("page layout" "rozloženie strany")
("page number" "číslo strany")
("page number rendering" "zobrazovanie čísiel strán")
("page number text" "text pre číslovanie strán")
("page numbering" "číslovanie strán")
("page reference" "odkaz na stranu")
("page rendering" "vykresľovanie strany")
("page right margin" "pravý okraj strany")
("page setup" "nastavenie strany")
("page top margin" "horný okraj strany")
("page type" "typ strany")
("page width" "šírka strany")
("pagedown" "pagedown")
("pages" "strany")
("pageup" "pageup")
("pale-blue" "bledo modrá")
("palette" "paleta")
("panorama" "panoráma")
("paper" "papier")
("paper size" "veľkosť papiera")
("paper type" "typ papiera")
("papyrus" "papyrus")
("paragraph" "odstavec")
("paragraph format" "formát odstavca")
("paragraph mode" "režim odstavca")
("paragraph width" "šírka odstavca")
("paragraph::section" "odstavec")
("paragraphs" "odstavce")
("parametric curve" "parametrická krivka")
("parametric surface" "parametrický povrch")
("parchment" "pergamen")
("parenthesis" "zátvorka")
("parenthesized" "v zátvorkách")
("parser" "parser")
("part" "časť")
("particle" "častica")
("passphrase decryption" "dešifrovanie s prístupovým heslo")
("passphrase encryption" "šifrovanie s prístupovým heslom")
("passphrase wallet facilities are not currently available" "funkcionalita hesla peňaženky nie je momentálne dostupná")
("passphrases are expected to have at least: 8 characters" "heslá musia mať najmenej: 8 znakov")
("passphrases mismatch" "heslá sa nezhodujú")
("password" "heslo")
("past changes" "minulé zmeny")
("paste" "vložiť")
("paste from" "vložiť z")
("paste text" "vložiť text")
("path" "cesta")
("pattern" "vzor")
("pattern selector" "výber vzoru")
("pause" "pozastaviť")
("pdf version number" "číslo verzie pdf")
("pen" "pero")
("pen width" "hrúbka pera")
("perform operations on cells" "vykonať operácie na bunkách")
("perform operations on columns" "vykonať operácie na stĺpcoch")
("perform operations on entire table" "vykonať operácie na celej tabuľke")
("perform operations on rows" "vykonať operácie na riadkoch")
("permanent" "trvalé")
("permanent footer" "trvalá päta")
("permanent header" "trvalá hlavička")
("permanently add to dictionary" "natrvalo pridať do slovníka")
("permanently insert into dictionary" "natrvalo vložiť do slovníka")
("permissions" "povolenia")
("person" "osoba")
("personal dictionary has been modified" "osobný slovník bol modifikovaný")
("phantasy" "fantázia")
("phantom" "fantóm")
("phantoms" "fantómy")
("philosophy" "filozofia")
("phoenician" "féničtina")
("phonetic" "fonetický")
("physics and astronomy class" "hodina fyziky a astronómie")
("picture" "obrázok")
("pine" "borovica")
("pink" "ružová")
("plain" "prostý")
("plain block" "prostý blok")
("plain boxes" "prosté boxy")
("plain circles" "prosté kruhy")
("plain tabular" "prostá tabuľka")
("planned changes" "plánované zmeny")
("plans for the future" "plány do budúcna")
("play" "prehrať")
("play all animations" "prehrať všetky animácie")
("play animation" "prehrať animáciu")
("please" "prosím")
("please install GnuPG software from https://www.gnupg.org" "prosím nainštalujte si GnuPG software z https://www.gnupg.org")
("please wait" "čakajte, prosím")
("plot" "graf")
("plots editor" "editor grafov")
("plug-ins" "plug-iny")
("plugin" "zásuvný modul")
("plugins" "zásuvné moduly")
("plural" "plurál")
("plus" "plus")
("point" "bod")
("point border" "bodové orámovanie")
("point size" "veľkosť bodu")
("point style" "štýl bodu")
("polar" "polárne")
("polish" "poľština")
("polygon" "mnohouholník")
("polynomial arithmetic" "polynomiálna aritmetika")
("pop server settings" "nastavenia pop servera")
("porting TeXmacs to other platforms" "portovanie TeXmacs-u na iné platformy")
("portion" "pomer")
("portrait" "na výšku")
("portuguese" "portugalčina")
("position" "umiestniť")
("position float" "umiestniť plávajúcu")
("position floating object" "umiestniť plávajúci objekt")
("position of marginal note" "umiestniť poznámku za okrajom")
("position the table" "umiestniť tabuľku")
("poster" "poster (plagát)")
("poster formats" "formáty posteru (plagátu)")
("poster theme" "téma 'poster (plagát)'")
("postfix" "pridať príponu")
("postscript" "postcrtipt")
("postscript image" "postrcriptový obrázok")
("pre-alpha release" "pre-alpha release")
("preamble" "preambula")
("preamble mode" "režim preambuly")
("preferences" "nastavenia")
("preferences for editing mathematical formulas" "nastavenia pre úpravu matematických vzorcov")
("preferences for tag" "nastavenia pre značku")
("prefix" "predpona")
("prefix by section number" "pridať číslo sekcie ako predponu")
("presentation" "prezentácia")
("presentation mode" "režim prezentácie")
("presentation tag" "prezentačná značka")
("presentation tool" "nástroj pre prezentácie")
("preserve" "zachovať")
("preserve tags" "zachovať značky (tags)")
("preserving syntactic correctness while editing mathematical formulas" "zachovávanie syntaktickej správnoti počas úprav matematických vzorcov")
("pretty" "pekné")
("pretty scheme tree output" "pekný výstup stromov jazyka scheme")
("pretty tree output" "pekný výstup stromov")
("preview" "náhľad")
("preview before printing" "náhľad pred tlačou")
("preview command" "príkaz náhľadu")
("preview with ghostview" "náhľad pomocou ghostview")
("previous" "predchádzajúci")
("previous difference" "predchádzajúci rozdiel")
("previous error" "predchádzajúca chyba")
("previous field" "predchádzajúce pole")
("previous occurrence" "predchádzajúci výskyt")
("previous screen" "predchádzajúca obrazovka")
("previous similar" "predchádzajúce podobné")
("primary" "primárny")
("prime" "čiarka (apostrof)")
("primitive or macro" "primitíva alebo makro")
("print" "tlač")
("print all" "tlačiť všetko")
("print all to file" "tlačiť všetko do súboru")
("print buffer" "tlačiť zásobník (buffer)")
("print buffer to file" "tlačiť zásobník (buffer) do súboru")
("print document" "tlačiť dokument")
("print page selection" "tlačiť označenú časť strany")
("print page selection to file" "tlačiť označenú časť strany do súboru")
("print to file" "tlačiť do súboru")
("print to postscript file" "tlačiť do postcriptového súboru")
("printer" "tlačiareň")
("printer dpi" "dpi tlačiarne")
("printer setup" "nastavenie tlačiarne")
("printing command" "príkaz pre tlač")
("problem" "problém")
("problems" "problémy")
("proceed" "pokračovať")
("produce Pdf using native export filter" "vytvoriť Pdf použitím natívneho exportovacieho filtra")
("produce Postscript using native export filter" "vytvoriť Postscript použitím natívneho exportovacieho filtra")
("professional" "profesionálny")
("prog" "prog")
("prog font" "písmo pre programy")
("prog font family" "rodina písma pre programy")
("prog font series" "séria písma pre programy")
("prog font shape" "tvar písma pre programy")
("program" "program")
("program bracket matching" "párovanie zátvoriek programu")
("program bracket selections" "výbery zátvoriek programu")
("program commands" "príkazy programu")
("program font" "písmo pre programy")
("program interface for buffer management" "rozhranie programu pre správu zásobníkov (buffer-ov)")
("program mode" "režim programu")
("programming" "programovanie")
("programming routines for editing documents" "programovacie rutiny pre úpravu dokumentov")
("progressive" "progresívny")
("project" "projekt")
("projector" "projektor")
("projects" "projekty")
("prologue" "prológ")
("prominent" "prominentný")
("prompt on scripts" "pýtať sa pri skriptoch")
("prompts and default input" "otázky a predvolený vstup")
("proof" "dôkaz")
("properties" "vlastnosti")
("proportional" "proporcionálny")
("proportional typewriter" "proporcionálne 'typewriter'")
("proposition" "tvrdenie")
("propositions" "tvrdenia")
("provoke C++ error" "vyvolať C++ chybu")
("provoke menu error" "vyvolať chybu menu")
("provoke scheme error" "vyvolať chybu scheme")
("pseudo code" "pseudokód")
("public key encryption" "šifrovanie s verejným kľúčom")
("public keys" "verejné kľúče")
("pulse" "pulzovať")
("qt GUI only, sorry. Use \"Export selection\"" "iba Qt GUI, prepáčte. Použite \"Exportovať vyznačené\"")
("qt-widgets" "qt-widgety")
("quadratic forms" "kvadratické formy")
("quantifier" "kvantifikátor")
("quasi" "kvázi")
("query replace" "nahradzovanie s otázkou")
("question" "otázka")
("questions" "otázky")
("questions only" "iba otázky")
("questions with answers" "otázky s odpoveďami")
("quick evaluation of formulas" "rýchle vyhodnocovanie vzorcov")
("quit" "koniec")
("quotation" "citát")
("quote" "úvodzovky")
("radius" "polomer")
("radius x" "polomer x")
("radius y" "polomer y")
("range" "rozsah")
("rank" "rank")
("raw" "surové (nespracované)")
("real" "reálne")
("really close it" "naozaj zavrieť")
("really delete user identity" "naozaj zmazať identitu užívateľa")
("really huge" "skutočne obrovský")
("really quit" "skutočne ukončiť")
("really tiny" "skutočne maličký")
("rebuild translations file" "znovuvytvoriť súbor s prekladmi")
("recent" "nedávne")
("recent documents" "nedávne dokumenty")
("recipients" "príjemcovia")
("recognize" "rozpoznať")
("recolor" "prefarbiť")
("recover autosave file" "obnoviť automaticky ukladaný súbor")
("rectangle" "obdĺžnik")
("rectangular" "obdĺžnikové")
("red" "červená")
("reddish" "dočervena")
("redo" "znovu vykonať")
("redo undone changes" "znovu vykonať odčinené zmeny")
("reduce" "zmenšiť")
("reduce bottom margin by" "zmenšiť spodný okraj o")
("reduce by" "zmenšiť o")
("reduce left margin by" "zmenšiť ľavý okraj o")
("reduce margins" "zmenšiť okraje")
("reduce right margin by" "zmenšiť pravý okraj o")
("reduce top margin by" "zmenšiť horný okraj o")
("reduce trigonometric functions" "redukovať trigonometrické funkcie")
("reduced margins" "zmenšené okraje")
("reduction even page margin" "zmenšenie okrajov párnej strany")
("reduction odd page margin" "zmenšenie okrajov nepárnej strany")
("reduction page bottom margin" "zmenšenie spodného okraja strany")
("reduction page right margin" "zmenšenie pravého okraja strany")
("reduction page top margin" "zmenšenie horného okraja strany")
("reference" "referencia")
("reference guide" "referenčná príručka")
("reference guide for the TeXmacs primitives" "referenčná príručka pre primitívy programu TeXmacs")
("reference guide for the standard TeXmacs styles" "referenčná príručka pre štandardné štýly programu TeXmacs")
("reference to note" "odkaz na poznámku")
("references" "odkazy")
("regenerate" "regenerovať")
("register" "registrovať")
("register file" "registrovať súbor")
("regular" "regulárny")
("relate" "dať do súvisu")
("relation" "vzťah")
("release" "release")
("release left button: finish editing" "pustiť ľavé tlačidlo: ukončiť úpravy")
("reload" "znovu načítať")
("remark" "poznámka")
("remarks" "poznámky")
("remote" "vzdialené")
("remote connections" "vzdialené spojenia")
("remote control" "vzdialené ovládanie")
("remote controllers with keyboard simulation" "vzdialené kontroléry so simuláciou klávesnice")
("remote directory" "vzdialený adresár (priečinok)")
("remote login" "vzdialené prihlásenie")
("remote plug-ins" "vzdialené pluginy")
("remote servers" "vzdialené servery")
("remote tool" "nástroj pre vzdialenú funkcionalitu")
("remove" "odstrániť")
("remove all output fields" "odstrániť všetky vstupné polia")
("remove animation" "odstrániť animáciu")
("remove argument after" "odstrániť parameter za")
("remove argument before" "odstrániť parameter pred")
("remove banner" "odstrániť baner")
("remove database entry" "odstrániť položku databázy")
("remove downwards" "odstrániť smerom dolu")
("remove entries" "odstrániť položky")
("remove entry" "odstrániť položku")
("remove field above" "odstrániť pole nad")
("remove field below" "odstrániť pole pod")
("remove fields" "odstrániť polia")
("remove folded" "odstrániť zbalené")
("remove from previous frames" "odstrániť z predošlých políčok (frames)")
("remove from subsequent frames" "odstrániť z nasledujúcich políčok (frames)")
("remove input field" "odstrániť vstupné pole")
("remove input field above" "odstrániť vstupné pole nad")
("remove last field" "odstrániť posledné pole")
("remove leftwards" "odstrániť smerom doľava")
("remove link" "odstrániť odkaz")
("remove next field" "odstrániť nasledujúce pole")
("remove number" "odstrániť číslo")
("remove overlay after" "odstrániť prekryvovú vrstvu po")
("remove overlay before" "odstrániť prekryvovú vrstvu pred")
("remove package" "odstrániť balíček")
("remove previous field" "odstrániť predošlé pole")
("remove remote ssh connection" "odstrániť vzdialené ssh spojenie")
("remove rightwards" "odstrániť smerov doprava")
("remove selected database entries" "odstrániť vybraté položky databázy")
("remove selected entries" "odstrániť označené položky")
("remove slide after" "odstrániť stranu prezentácie (slide) po")
("remove slide before" "odstrániť stranu prezentácie (slide) pred")
("remove superfluous invisible operators" "odstrániť nadbytočné neviditeľné operátory")
("remove tag" "odstrániť značku")
("remove this branch" "odstrániť túro vetvu")
("remove this frame" "odstrániť tento rámec")
("remove this switch" "odstrániť tento prepínač")
("remove unfolded" "odstrániť odbalené")
("remove upwards" "odstrániť smerom hore")
("removed entries from database" "položky odstránené z databázy")
("removed entry from database" "položka odsránená z databázy")
("rename" "premenovať")
("rename section" "premenovať sekciu")
("rendering" "vykresľovanie")
("rendering options for tag" "možnoti vykresľovania pre značku (tag)")
("renumber this page" "prečíslovať túto stranu")
("repeat" "opakovať")
("repeat object" "opakovať objekt")
("replace" "nahradiť")
("replace TeXmacs styles with no LaTeX equivalents" "nahradiť TeXmacsové štýly nemajúce LaTeXové ekvivalenty")
("replace all further occurrences" "nahradiť všetky ďalšie výskyty")
("replace by" "nahradiť")
("replace one occurrence" "nahradiť jeden výskyt")
("replace toolbar" "nahradiť panel nástrojov")
("replace unrecognized styles" "nahradiť nerozpoznané štýly")
("replaced" "nahradené")
("replaced one occurrence" "jeden výskyt nahradený")
("research papers" "vedecké články (výskumné práce)")
("reset" "reset")
("reset error counters" "resetovať počítadlá chýb")
("resize" "zmena rozmerov")
("resize object" "zmena rozmerov objektu")
("resize objects" "zmena rozmerov objektov")
("resized" "rozmery zmenené")
("restart TeXmacs in order to let changes take effect" "reštartovať TeXmacs aby sa prejavili zmeny")
("restart in order to let the new look and feel take effect" "reštartovať aby sa prejavil nový vzhľad a štýl ovládania")
("retain" "ponechať")
("retime" "zmeniť časovanie")
("retina settings" "nastavenia 'retina'")
("retrieve email" "načítať email")
("retrieve remote live document" "načítať vzdialený dokument")
("retrieved contents" "obsah načítaný")
("retro" "retro")
("return" "return")
("reverse" "obrátiť")
("reverse ordering" "obrátené poradie")
("revert" "odčiniť")
("revert buffer" "obnoviť zásobník (buffer)")
("rewriting" "prepisovanie")
("ridged paper" "ryhovaný papier")
("ridged-paper" "ryhovano-papierové")
("right" "pravý")
("right aligned" "zarovnaný vpravo")
("right arrow" "pravá šípka")
("right baseline" "pravé učiarie (základná dotyčnica)")
("right border" "pravé orámovanie")
("right cell border" "pravé orámovanie bunky")
("right cell padding" "pravý odskok bunky")
("right down" "vpravo dolu")
("right margin" "pravý okraj")
("right on even pages" "vpravo na párnych stranách")
("right padding" "odskakovanie vpravo")
("right subscript" "pravý dolný index (subskript)")
("right superscript" "pravý horný index (superskript)")
("right surrounding" "pravé okolie")
("right table border" "pravé orámovanie tabuľky")
("right table padding" "pravé odskakovanie tabuľky")
("right up" "vpravo hore")
("rightwards" "smerov doprava")
("rigid" "pevná")
("rigid box" "pevný box")
("rigid horizontal" "pevný vodorovne")
("rigid space" "pevná medzera")
("ring binder notebook style" "štýl 'karisblok'")
("romanian" "rumunčina")
("root" "koreň")
("rotate" "otočiť")
("rotate backward" "otočiť vzad")
("rotate forward" "otočiť vpred")
("rotate objects" "otočiť objekt")
("rough" "drsné")
("rough paper" "drsný papier")
("rough-paper" "drosno-papierové")
("round" "okrúhle")
("round overbrace" "zaoblená horná svorka")
("round underbrace" "zaoblená spodná svorka")
("rounded" "zaoblené")
("row" "riadok")
("row above" "riadok nad")
("row below" "riadok pod")
("row contains glued items" "riadok obsahuje zlepené položky")
("rows" "riadky")
("run" "spustiť")
("run current file" "spustiť aktuálny súbor")
("runic" "runy")
("running author" "priebežný autor")
("running title" "priebežný nadpis")
("russian" "ruština")
("same names" "rovnaké názvy")
("same screen margins as on paper" "rovnaké okraje na obrazovke ako na papieri")
("sample" "vzorka")
("sample text" "ukážkový text")
("sans serif" "bez pätiek (sans serif)")
("save" "uložiť")
("save TeXmacs file" "uložiť súbor TeXmacs")
("save TeXmacs style file" "uložiť súbor štýlu TeXmacs")
("save all embedded images" "uložiť všetky vložené obrázky")
("save as" "uložiť ako")
("save as LaTeX" "uložiť ako LaTeX")
("save as TeX" "uložiť ako TeX")
("save auxiliary data" "uložiť pomocné dáta")
("save buffer" "uložiť zásobník (buffer)")
("save buffer as" "uložiť zásobník (buffer) ako")
("save entries" "uložiť položky")
("save entry" "uložiť položku")
("save file" "uložiť súbor")
("save html file" "uložiť súbor html")
("save image" "uložiť obrázok")
("save image as" "uložiť obrázok ako")
("save latex file" "uložiť súbor latex")
("save position" "uložiť polohu")
("save remote file" "uložiť vzdialený")
("save tex file" "uložiť súbor tex")
("save this buffer" "uložiť tento zásobník (buffer)")
("save verbatim file" "uložíť súbor verbatim")
("saved" "uložené")
("saved modifications in database" "zmeny uložené v databáze")
("scheme command" "príkaz jazyka scheme")
("scheme developers guide" "príručka pre vývojárov scheme")
("scheme extensions" "rozšírenia v scheme")
("scheme interface for the graphical mode" "rozhranie jazyka scheme pre grafický režim")
("screen" "obrazovka")
("screen layout" "rozvrhnutie obrazovky")
("screen margins" "okraje na obrazovke")
("screen rendering" "vykresľovanie na obrazovke")
("screens" "obrazovky")
("screenshot" "snímka obrazovky")
("script" "indexy")
("script above" "index nad")
("script below" "index pod")
("script script size" "veľkosť indexu indexu")
("script size" "veľkosť indexu")
("scripting language" "skriptovací jazyk")
("scripts" "indexy")
("scripts not accepted" "skripty (indexy?) nie sú povolené")
("search" "hľadať")
("search and replace" "hľadať a nahradiť")
("search in database" "hľadať v databáze")
("search results for" "výsledky vyhľadávania pre")
("search toolbar" "nástrojová lišta pre vyhľadávanie")
("search words in my documents" "hľadané slová v mojom dokumente")
("search words in the documentation" "hľadané slová v dokumentácii")
("search words in the source code" "hľadané slová v zdrojovom kóde")
("searching" "vyhľadávam")
("second" "druhý")
("secondary" "sekundárny")
("secret keys" "privátne kľúče")
("section" "sekcia")
("sections" "sekcie")
("security" "bezpečnosť")
("see" "viď")
("see documentation" "viď dokumentáciu")
("select GnuPG recipients" "zvoliť GnuPG príjemcov")
("select a document style" "zvoliť stýl dokumentu")
("select a foreground color" "zvoliť farbu popredia")
("select a language" "zvoliť jazyk")
("select background picture" "zvoliť obrázok pozadia")
("select color" "zvoliť farbu")
("select document style" "zvoliť štýl dokumentu")
("select pen" "zvoliť pero")
("select the action to be undertaken for each conflict" "zvoliť akciu, ktorá sa má vykonať pre každý konflikt")
("select view mode" "režim výberu pohľadu")
("selected region" "vybraná oblasť")
("selection" "označená časť")
("selections" "označené časti")
("semantic correctness" "sémantická správnosť")
("semantic editing" "sémantické editovanie")
("semantic selections" "sémentické výbery")
("semantics" "sémantika")
("seminar" "seminár")
("sending commands to TeXmacs" "posielanie príkazov do TeXmacsu")
("senior" "senior")
("separation between lines" "oddelenie riadkov")
("separation between paragraphs" "oddelenie medzi odstavcami")
("separator" "oddeľovač")
("september" "september")
("serb" "srbčina")
("series" "séria")
("series|right" "séria|vpravo")
("serif" "pätkové (serif)")
("server" "server")
("server licence agreement" "licenčná zmluva pre server")
("session" "sedenie")
("session commands" "príkazy sedenia")
("session name" "názov sedenia")
("session type" "typ sedenia")
("sessions" "sedenia")
("set" "nastaviť")
("set background color of cell" "nastaviť farbu pozadia bunky")
("set cell mode" "nastaviť režim bunky")
("set default" "nastaviť predvolené")
("set difference" "nastaviť rozdiel")
("set extension center" "nastaviť stred rozšírenia")
("set height" "nastaviť výšku")
("set height of cell" "nastaviť výšku bunky")
("set intersection" "nastaviť priesečník")
("set margins" "nastaviť okraje")
("set n" "nastavte n")
("set number of columns" "nastaviť počet stĺpcov")
("set number of rows" "nastaviť počet riadkov")
("set or get environment variables" "nastavenie alebo zistenie premenných prostredia")
("set paragraph margins" "nastaviť okraje odstavca")
("set paragraph mode" "nastaviť režim odstavca")
("set printer dpi" "nastaviť dpi tlačiarne")
("set printing command" "nastaviť príkaz pre tlač")
("set properties" "nastaviť vlastnosti")
("set span" "nastaviť rozpätie")
("set special cell properties" "nastaviť špeciálne vlastnosti bunky")
("set special table properties" "nastaviť špeciálne vlastnosti tabuľky")
("set text width" "nastaviť šírku textu")
("set union" "nastaviť zjednotenie")
("set user information" "nastaviť informácie o užívateľovi")
("set width" "nastaviť šírku")
("set width of cell" "nastaviť šírku bunky")
("settings" "nastavenia")
("setup printer" "nastavenie tlačiarne")
("seventh" "siedme")
("several equations" "viacero rovníc")
("shadow" "tieňovanie")
("shadowed" "tieňované")
("shadowed raise" "zvýšiť tieňovanie?")
("shape" "tvar")
("sharpness" "ostrosť")
("shift" "posun")
("shift-down" "shift-dolu")
("shift-right" "shift-doprava")
("shift::keyboard" "shift")
("short" "krátky")
("shortcut" "klávesová skratka")
("show" "zobratiť")
("show all parts" "zobraziť všetky časti")
("show current focus" "zobraziť aktuálny fokus")
("show full context" "zobraziť úplný kontext")
("show grid" "zobraziť mriežku")
("show header and footer" "zobrazovať hlavičku a pätu")
("show hidden" "zobraziť skryté")
("show key presses" "zobraziť stlačenia klávesov")
("show main document" "zobraziť hlavný dokument")
("show memory usage" "zobraziť využitie pamäte")
("show on screen" "zobraziť na obrazovke")
("show one part" "zobraziť jednu časť")
("show panorama" "zobraziť panorámu")
("show preamble" "zobraziť preambulu")
("show several parts" "zobraziť viacero častí")
("show subunits" "zobraziť podjednotky")
("show table cells" "zobraziť bunky tabuľky")
("show timings" "zobraziť časovania")
("shrinking factor" "zmenšenie")
("side tools" "bočné nástroje")
("signature" "podpis")
("simple" "jednoduché")
("simple form" "jednoduchá forma")
("simple widget" "jednoduchý widget")
("simplification" "zjednodušenie")
("simplified evaluation of formulas" "zjednodušené vyhodnocovanie vzorcov")
("simplified menus" "zjednodušené menu")
("simplify" "zjednodušiť")
("sine" "sínus")
("sine and cosine" "sínus a kosínus")
("sixth" "šiesty")
("size" "veľkosť")
("size limits" "veľkostné limity")
("size tag" "veľkostná značka")
("skew" "zošikmenie")
("skin" "koža")
("skip all" "vynechať všetky")
("slant" "sklon")
("slanted" "sklonené")
("slashed fraction" "zlomok s lomkou")
("slide" "strana prezentácie (slide)")
("slides" "strany prezentácie (slides)")
("sloppy" "nedbalé")
("slovene" "slovinčina")
("slow" "pomalé")
("slow decrease" "pomalé znižovanie")
("slow increase" "pomalé zvyšovanie")
("small" "malý")
("small Capitals" "kapitálky")
("small capitals" "kapitálky")
("small caps" "kapitálky")
("small environment box" "box pre malé prostredie")
("small figure" "malý obrázok")
("small focus" "malý fokus")
("small inline" "malé v riadku")
("small inline fraction" "malý zlomok v riadku")
("small skip" "malý odstup")
("small table" "malá tabuľka")
("smash" "rozbiť")
("smooth" "plynulé")
("smooth end" "plynulý koniec")
("smooth extremities" "plynulé extrémy")
("smooth start" "plynulý začiatok")
("snap" "pritiahnuť/prichytiť")
("snap distance" "vzdialenosť pre pritiahnutie/prichytenie")
("snap to curves" "priťahovať/prichytávať na krivky")
("snap to grid" "priťahovať/prichytávať na mriežku")
("snap to grid curve" "priťhovať/prichytávať na krivku mriežky")
("snap to intersections of curves" "priťahovať/prichytávať na priesečníky kriviek")
("snap to pages" "priťahovať/prichytávať na strany")
("snap to text borders" "priťahovať/prichytávať na okraje textu")
("snap to text corners" "priťahovať/prichytávať na rohy textu")
("solution" "riešenie")
("solution to exercise" "rišenie cvičenia")
("solution to problem" "riešenie problému")
("solutions" "riešenia")
("solve" "riešiť")
("solve in" "riešiť v")
("solving equations" "riešenie rovníc")
("sound" "zvuk")
("source" "zdroj")
("source code" "zdrojový kód")
("source directory" "zdrojový adresár (priečinok)")
("source macros tool" "zdrojový nástroj makier")
("source tags" "zdrojové značky")
("south" "juh")
("south east" "juhovýchod")
("space" "medzera")
("space bar in math mode" "medzerník v matematickom režime")
("space bar in text mode" "medzerník v textovom režime")
("space between lines" "medzera medzi riadkami")
("space between paragraphs" "medzera medzi odstavcami")
("space stretchability" "natiahnuteľnosť medzier")
("spacing" "medzery")
("span" "rozpätie")
("span over all columns" "rozpätie cez všetky sĺpce")
("spanish" "španielčina")
("special" "špeciálne")
("special cell properties" "špeciálne vlastnosti bunky")
("special cell properties and actions" "špeiálne vlastnosti a akcie bunky")
("special functions" "špeciálne funkcie")
("special properties" "špeciálne vlastnosti")
("special table properties" "špeciálne vlastnosti tabuľky")
("specific" "špecifické")
("specific baseline" "špecifické na učiarie (základná dotyčnica)")
("specified" "zadané")
("specify color alternation" "špecifikovať striedanie farieb")
("specify how to traverse the manual" "špecifikovať ako prechádzať manuálom")
("specify semantics of a symbol or formula" "špecifikovať sémantiku znaku alebo vzorca")
("specify the size of the table" "špecifikovať veľkosť tabuľky")
("specify user identity" "zadať identitu užívateľa")
("spell" "pravopis")
("spell check" "kontrola pravopisu")
("spell checking complete" "kontrola pravopisu dokončená")
("spelling error" "pravopisnu chyba")
("spelling errors have been corrected" "pravopisné chyby boli opravené")
("spline" "splajn")
("split" "rozdeliť")
("split program" "rozdeliť program")
("split session" "rozdeliť sedenie")
("square" "štvorec")
("square overbrace" "hranatá horná svorka")
("square root" "druhá odmocnina")
("square underbrace" "hranatá dolná svorka")
("stack" "zásobník (stack)")
("standard" "štandardné")
("standard Output" "štandardný Výstup")
("standard TeXmacs styles" "štandardné TeXmacs štýly")
("standard environment variables" "štandardné premenné prostredia")
("standard formats" "štandardné formáty")
("standard fraction" "štandardný zlomok")
("star" "hviezdička")
("start" "začiatok")
("start a new chapter" "začať novú kapitolu")
("start a new section" "začať novú sekciu")
("start an interactive session" "začasť interaktívne sedenie")
("start remote session" "začať vzdialené sedenie")
("start server" "spustiť server")
("statement" "vyhlásenie")
("statistics" "štatistika")
("status" "stav")
("status bar" "stavový riadok")
("stop server" "zastaviť server")
("storage" "úložisko")
("store tracking information in LaTeX files" "ukladať info o sledovaní do súborov LaTeX")
("strength" "sila")
("stretch" "roztiahnuť")
("stretch factor" "faktor roztiahnutia")
("stretchable" "roztiahnuteľné")
("stretchable horizontal" "vodorovne roztiahnuteľné")
("stretchable vertical" "zvislo roztiahnuteľné")
("stretched" "roztiahnuté")
("strict Ascii" "striktné Ascii")
("strike through" "prečiarknuť")
("string" "reťazec")
("stroke" "ťah")
("strokes" "ťahy")
("strong" "silne")
("structural" "štrukturálne")
("structured insert above" "štrukturované vloženie nad")
("structured insert at the left" "štrukturované vloženie vľavo")
("structured insert at the right" "štrukturované vloženie vpravo")
("structured insert below" "štruktorované vloženie pod")
("structured remove downwards" "štrukturované odstránenie nadol")
("structured remove leftwards" "štrukturované odstránenie doľava")
("structured remove rightwards" "štrukturované odstránenie doprava")
("structured remove upwards" "štrukturované odstránenie nahor")
("structured variant" "štrukturovaný variant")
("style" "štýl")
("style options" "možnosti štýlu")
("style parameters" "parametre štýlu")
("styles" "štýly")
("stylesheet language" "'stylesheet' jazyk")
("sub" "pod-")
("subject" "predmet")
("submenu" "podmenu")
("subparagraph" "pododstavec")
("subparagraphs" "pododstavce")
("subscript" "dolný index")
("subscript below" "dolný index pod")
("subsection" "podsekcia")
("subsections" "podsekcie")
("subsub" "podpod-")
("subsubmenu" "podmenu")
("subsubsection" "podpodsekcia")
("subsubsections" "podpodsekcie")
("subsubsubmenu" "podpodpodmenu")
("subsubsubsubmenu" "podpodpodpodmenu")
("subtable" "podtabuľka")
("subtitle" "podnadpis")
("subtraction" "odčítanie")
("summarized" "zhrnuté")
("summary" "zhrnutie")
("summary of the principal TeXmacs tags" "zhrnutie hlavných tagov TeXmacs-u")
("superpose" "superpozícia")
("superposed" "superponované")
("superscript" "horný index")
("superscript above" "horný index nad")
("supported plug-ins" "podporované zásuvné moduly")
("surface" "povrch")
("surveys" "prieskumy")
("swedish" "švédčina")
("swell" "nafúknuť")
("swiss" "švajčiarčina")
("switch" "prepínač")
("switch to buffer" "prepnúť na zásobník (buffer)")
("switch to first" "prepnúť na prvé")
("switch to formula style" "prepnúť na štýl vzorca")
("switch to last" "prepnúť na posledné")
("switch to next" "prepnúť na nasledujúce")
("switch to previous" "prepnúť na predchádzajúce")
("switching and folding" "prepínanie a zbaľovanie")
("symbol" "symbol (znak)")
("symbol browser" "prehliadač symbolov (znakov)")
("symbol properties not found" "vlastnosti symbolu (znaku) neboli nájdené")
("symbols" "symboly (znaky)")
("synchronization status" "stav synchronizácie")
("synchronize" "synchronizovať")
("synchronize bibliographic references" "synchronizovať bibliografické odkazy (literatúru)")
("synchronize file or directory" "synchronizovať súbor alebo adresár (priečinok)")
("synchronize with remote server" "synchronizovať so vzdialeným serverom")
("synopsis" "súhrn")
("system command" "systémový príkaz")
("system environment variables" "premenné prostredia systému")
("tab" "tabulátor")
("tab-completion" "dopĺňanie tabulátorom")
("tabbed" "tabulované")
("table" "tabuľka")
("table breaking" "zalamovanie tabuľky")
("table command" "príkaz tabuľky")
("table height" "výška tabuľky")
("table of contents" "obsah")
("table properties" "vlastnosti tabuľky")
("table width" "šírka tabuľky")
("tables" "tabuľky")
("tabular" "tabelárny")
("tabular material" "tabelárny materiál")
("tag" "značka (tag)")
("tags with special rendering" "značky so špeciálnym vykresľovaním")
("taiwanese" "taiwančina")
("tangent" "tangens")
("target" "cieľ")
("teXmacs DTD" "DTD TeXmacsu")
("teXmacs as an interface" "teXmacs ako rozhranie")
("teXmacs buffer expected" "očakáva sa zásobník (buffer) TeXmacsu")
("teXmacs buffer on disk expected" "očakáva sa zásobník (buffer) TeXmacsu na disku")
("teXmacs database preferences" "databázové nastavenia TeXmacsu")
("teXmacs extensions to scheme and utilities" "rozšírenia TeXmacsu do scheme a nástroje")
("teXmacs fonts" "fonty TeXmacsu")
("teXmacs macro" "TeXmacsové makro")
("teXmacs manual" "manuál TeXmacsu")
("teXmacs manuel" "manuál TeXmacsu")
("teXmacs notice" "oznámenie TeXmacsu")
("teXmacs package" "balíček TeXmacsu")
("teXmacs plugins" "zásuvné moduly TeXmacsu")
("teXmacs primitives" "primitívy TeXmacsu")
("teXmacs style" "štýl TeXmacsu")
("teXmacs style files" "súbory so štýlmi TeXmacsu")
("teXmacs website" "webové sídlo TeXmacsu")
("teXmacs-related work" "práca súvisiaca s TeXmacsom")
("ternary" "terciálny")
("test" "test")
("test routine" "testovacia rutina")
("testing tree-view" "testovací stromový pohľad")
("tex" "tex")
("text" "text")
("text borders" "okraje textu")
("text box style" "štýl textového boxu")
("text corners" "rohy textu")
("text font" "písmo pre text")
("text for note" "text pre poznámku")
("text height correction" "oprava výšky textu")
("text padding" "odskok textu")
("text width" "šírka textu")
("texts" "texty")
("textual" "textové")
("textual operator" "textový operátor")
("textual spreadsheet" "textová výpočtová tabuľka (spreadsheet)")
("textual table" "textová tabuľka")
("th century bc" "-te storočie p.n.l.")
("th root" "-ta odmocnina")
("thai" "taičina")
("the TeXmacs authors" "autori TeXmacsu")
("the TeXmacs format" "formát TeXmacsu")
("the TeXmacs plug-in system" "systém zásuvých modulov TeXmacsu")
("the application did not send its usual startup banner" "aplikácia nezaslala obvyklú štartovaciu správu")
("the application does not reply" "aplikácia nereaguje")
("the application is already running" "aplikácia je už spustená")
("the boxes produced by the typesetter" "boxy generované sádzačom")
("the buffer has not been saved" "zásobník (buffer) nebol uložený")
("the document has not been saved" "dokument nebol uložený")
("the graphical user interface" "grafické užívateľské rozhranie")
("the leaves of TeXmacs trees" "listy stromov TeXmacsu")
("the mycas example" "príklad systému mycas")
("the primitive TeXmacs constructs" "základné (primitívne) konštrukty TeXmacsu")
("the standard TeXmacs styles" "štandardné štýly TeXmacsu")
("theme" "téma")
("theme parameters" "parametre témy")
("theorem" "teorém")
("theorems" "teorémy")
("there are unsaved documents" "niektoré dokumenty nie sú uložené")
("there are unsaved files" "niektoré súbory nie sú uložené")
("these collected public keys will be definitely lost" "tieto zozbierané verejné kľúče budú definitívne stratené")
("these public keys will be definitely lost" "tieto verejné kľúče budú definitívne stratené")
("these secret keys will be definitely lost" "tieto privátne kľúče budú definitívne stratené")
("thicken" "zväčšiť hrúbku")
("thickness" "hrúbka")
("thin" "tenké")
("third" "tretí")
("this" "tento")
("this article has been written using" "tento článok bol napísaný použitím")
("this buffer has not been saved" "tento zásobník (buffer) nebol uložený")
("this column" "tento stĺpec")
("this document has been produced using" "tento dokument bol vytvorený použitím")
("this document has been written using" "tento tento dokument bol napísaný použitím")
("this document has not been saved" "tento dokument nebol uložený")
("this line" "tento riadok")
("this page" "táto strana")
("this page footer" "táto päta")
("this page header" "táto hlavička")
("this row" "tento riadok")
("this style specifies page margins in the TeX way" "tento štýl špecifikuje okraje strany TeX-ovým spôsobom")
("three columns" "tri stĺpce")
("three dots" "tri bodky")
("three times" "trikrát")
("threshold" "prah")
("through the menus" "prostredníctvom menu")
("through popup windows" "prostredníctvom vyskakovacích okien")
("thumbnails" "miniatúry")
("tilda" "tilda")
("tilde" "vlnovka (tilda)")
("time evolution" "časový vývoj")
("times" "krát")
("timings" "časovania")
("tiny" "maličký")
("title" "nadpis")
("title presentation options" "možnosti názvu prezentácie")
("title style" "štýl názvu")
("title suffix" "prípona názvu")
("titled block" "nazvaný blok")
("to the left" "naľavo")
("to the right" "napravo")
("today" "dnes")
("toggle cell wrapping mode" "prepnúť režim zalamovania")
("toggle here" "prepnúť sem")
("toggle name" "prepnúť meno")
("toggle numbering" "prepnúť číslovanie")
("toggle off" "prepnúť (na) vypnuté")
("toggle on" "prepnúť (na) zapnuté")
("toggle specification" "prepnúť špecifikáciu")
("toggle titled" "prepnúť nazvané")
("tolerant" "tolerantné")
("tools" "nástroje")
("top" "vrch")
("top baseline" "vrchné učiarie (základná dotyčnica)")
("top border" "horné orámovanie")
("top cell border" "horné orámovanie bunky")
("top cell padding" "horný odskok")
("top level" "najvyššia úroveň")
("top margin" "horné orámovanie")
("top padding" "horný odskok")
("top table border" "horné orámovanie tabuľky")
("top table padding" "horný odskok tabuľky")
("topless title" "názov bez vrchu")
("transform" "transformovať")
("transform cell into subtable" "transformovať bunku na podtabuľku")
("transformations" "transformácie")
("translate" "posunúť")
("translate::language" "preložiť")
("translations" "preklady")
("translations loaded" "preklady načítané")
("transpose" "transponovať")
("traversal" "prechádzanie")
("traverse" "prechádzať")
("tree" "strom")
("triangle" "trojuholník")
("triangular list items" "trojuholníkové položky zoznamu")
("triangularize" "triangulovať")
("trigonometric" "trigonometrické")
("trigonometric functions" "trigonometrické funkcie")
("trigonometry" "trigonometria")
("try to import formulas using LaTeX annotations" "pokúsiť sa importovať vzorce použitím LaTeXových anotácií")
("tuple" "n-tica")
("turkish" "turečtina")
("turn off" "vypnúť")
("turn on" "zapnúť")
("turn on wallet" "zapnúť peňaženku")
("tutorial" "sprievodca začiatočníka (tutoriál)")
("tutorials" "tutoriály")
("twice" "dvakrát")
("two columns" "dva stĺpce")
("two dots" "dve bodky")
("type" "typ")
("type a LaTeX command followed by" "napíšte príkaz LaTeXu nasledovaný")
("type a latex command followed by" "napíšte príkaz latexu nasledovaný")
("type a latex command followed by return" "napíšte príkaz latexu nasledovaný enterom")
("type body" "napíšte telo")
("type denominator" "napíšte menovateľ")
("type numerator" "napíšte čitateľ")
("type script" "napíšte skript")
("typesetted boxes" "vysádzané boxy")
("typewriter" "písací stroj")
("typewriter small caps" "písací stroj kapitálky")
("typing a simple text" "písanie jednoduchého textu")
("typing simple texts" "písanie jednoduchých textov")
("uTF-8 with inputenc LaTeX package" "uTF-8 s LaTeXovým balíčkom inputenc")
("ugaritic" "ugurčina")
("ukrainian" "ukrajinčina")
("ultra compact" "ultra kompaktné")
("unchanged" "nezmenené")
("underbrace" "spodná svorka")
("underline" "podčiarknutie")
("underlined" "podčiarknuté")
("undo" "odčiniť")
("undo last changes" "odčiniť posledné zmeny")
("unevaluated argument" "nevyhodnotený parameter")
("unevaluated value" "nevyhodnotená hodnota")
("unextended" "nerozšírené")
("unfold" "odbaliť")
("unfold all" "odbaliť všetko")
("unfold all fields" "odbaliť všetky polia")
("unfolded" "odbalené")
("ungroup" "odskupiť")
("unit" "jednotka")
("unit length" "jednotková dĺžka")
("unknown secret key fingerprint" "odučiť sa odtlačok privátneho kľúča")
("unpublished" "nepublikované")
("unregistered file" "neregistrovaný súbor")
("unroll" "rozvinúť")
("unsecure script refused" "nie-bezpečný skript odmietnutý")
("unsupported link mode" "nepodporovaný režim odkazov")
("until" "až kým")
("untitled block" "blok bez názvu")
("up" "hore")
("up to date" "aktuálny")
("update" "aktualizovať")
("update buffer" "aktualizovať zásobník (buffer)")
("update from web" "aktualizovať z webu")
("update image links" "aktualizovať odkazy na obrázky")
("update remote ssh connection" "aktualizovať vzdialené ssh spojenie")
("update this buffer" "aktualizovať tento zásobník (buffer)")
("update web site" "aktualizovať webové stránky (web site)")
("upgrade" "upgradovať")
("upight" "")
("upload" "nahrať")
("upload file or directory" "nahrať súbor alebo adresár (priečinok)")
("upper border" "horné orámovanie")
("upright" "vzpriamený")
("upwards" "smerom hore")
("url" "url")
("use CSS for more advanced formatting" "pre pokročilejšie formátovanie použiť CSS")
("use Inkscape for conversion from SVG" "pre konverziu zo SVG použiť Inkscape")
("use MathML" "použiť MathML")
("use TeXmacs" "použiť TeXmacs")
("use a black color" "použiť čiernu farbu")
("use a blue color" "použiť modrú farbu")
("use a bold font" "použiť hrubé písmo")
("use a brown color" "použiť hnedú farbu")
("use a calligraphic font" "použiť kaligrafické písmo")
("use a green color" "použiť zelenú farbu")
("use a grey color" "použiť sivú farbu")
("use a magenta color" "použiť purpurovú farbu")
("use a orange color" "použiť oranžovú farbu")
("use a pink color" "použiť ružovú farbu")
("use a red color" "použiť červenú farbu")
("use a sans serif font" "použiť bezpätkové písmo (sans serif)")
("use a typewriter font" "použiť písmo 'písací stroj'")
("use a white color" "použiť bielu farbu")
("use a yellow color" "použiť žltú farbu")
("use as master" "použiť ako 'master'")
("use blackboard bold font" "použiť hrubé písmo blackboard")
("use bold font series" "použiť sériu hrubých písiem")
("use calligraphical font" "použiť kaligrafické písmo")
("use custom note symbol" "použiť vlastný symbol poznámky")
("use extensible brackets" "použiť rozšíriteľné zátvorky")
("use footnote font size" "použiť veľkosť písma poznámky pod čiarou")
("use fraktur font" "použiť písmo fraktur")
("use high resolution fonts" "použiť písma s vysokým rozlíšením")
("use high resolution icons" "použiť ikony s vysokým rozlíšením")
("use huge font size" "použiť obrovskú veľkosť písma")
("use italic font shape" "použiť tvar písma latinka")
("use large font size" "použiť veľkú veľkosť písma")
("use left hand column as border" "použiť ľavý stĺpec ako okraj (orámovanie)")
("use line wrapping for lines which are longer than 80 characters" "")
("use margin kerning (protrusion)" "použiť kerning okrajov (vyčnievanie)")
("use medium font series" "použiť sériu stredne veľkého písma")
("use normal font size" "použiť normálnu veľkosť písma")
("use package" "použiť balíček")
("use paragraph width" "použiť širku odstavca")
("use print dialogue" "použiť dialógové okno tlače")
("use protrusion" "použiť vyčnievanie")
("use really huge font size" "použiť naozaj obrovskú veľkosť písma")
("use relative path" "požiť relatívnu cestu")
("use retina fonts" "použiť retina písma")
("use retina icons" "použiť retina písma")
("use right font shape" "použiť tvar písma sprava")
("use right hand column as border" "použiť pravý stĺpec ako okraj (orámovanie)")
("use roman font family" "použiť rodinu písiem roman")
("use row above as border" "použiť riadok nad ako okraj (orámovanie)")
("use row below as border" "použiť riadok pod ako okraj (orámovanie)")
("use sans serif font family" "použiť bezpätkovú rodinu písiem (sans serif)")
("use script font size" "použiť veľkosť písma skript")
("use slanted font shape" "použiť sklonený tvar písma")
("use small capitals" "použiť kapitálky")
("use small font size" "použiť malú veľkosť písma")
("use small-caps font shape" "použiť veľkosť písma kapitálky")
("use the blackboard bold font" "použiť hrubé písmo blackboard")
("use the fraktur font" "použiť písmo fraktur")
("use tiny font font size" "použiť veľkosť písma 'maličké písmo'")
("use typewriter font family" "použiť rodinu písiem 'písací stroj'")
("use unified toolbars" "použiť zjednotený panel nástrojov")
("use very large font size" "použiť veľmi veľkú veľkosť písma")
("user interface" "užívateľské rozhranie")
("user interface language" "jazyk užívateľského rozhrania")
("user manual" "používateľská príručka")
("user preferences" "užívateľské nastavenia")
("user provided icons" "užívateľom poskytnuté ikony")
("users of Cyrillic languages" "používatelia azbukových (cyrilických) jazykov")
("users of oriental languages" "používatelia orientálych jazykov")
("utf-8 with inputenc" "utf-8 s inputenc")
("utf-8 with inputenc LaTeX package" "utf-8 s LaTeX-ovým balíčkom inputenc")
("utilities" "pomocné programy")
("value" "hodnota")
("vanish" "zmiznúť")
("variable" "premenná")
("variant" "variant")
("vector" "vektor")
("verbatim" "verbatim")
("verbose" "rozvláčne")
("verse" "verš")
("version" "verzia")
("versioning tool" "nástroj na správu verzií")
("vertical" "zvislé")
("vertical after" "zvislé za")
("vertical alignment" "zvislé zarovnanie")
("vertical before" "zvislé pred")
("vertical cell alignment" "zvislé zarovnanie bunky")
("vertical margins" "zvislé okraje")
("vertical padding" "zvislý odskok")
("vertical part" "zvislá časť")
("vertical position" "zvislá poloha")
("vertical space" "zvislá medzera")
("vertical space after" "zvislá medzera za")
("vertical space before" "zvislá medzera pred")
("vertical space stretchability" "zvislá roztiahnuteľnosť medzier")
("vertical table alignment" "zvislé zarovnanie tabuľky")
("vertically align cell to the base" "zvislo zarovnať bunku na základňu")
("vertically center the cell" "zvislo vycentrovať bunku")
("very large" "veľmi veľké")
("very small" "veľmi malé")
("vietnamese" "vietnamčina")
("view" "pohľad")
("visible" "viditeľné")
("visible except here" "viditeľné okrem tohoto miesta")
("visible from here on" "viditeľné od tohoto miesta")
("visible only here" "viditeľné iba tu")
("visible until here" "viditeľné po toto miesto")
("visited color" "farba navštíveného")
("visited loci" "navštívené miesta (loci)")
("volume" "hlasitosť")
("wallet" "peňaženka")
("warning" "varovanie")
("warnings" "varovania")
("wave" "vlna")
("wave length x" "vlnová dĺžka x")
("wave length y" "vlnová dĺžka y")
("web" "web")
("weight" "váha")
("welcome" "vitajte")
("welcome to GNU TeXmacs" "vitajte v GNU TeXmacse")
("what is new" "čo je nové")
("when finished" "po dokončení")
("when line wrapping" "pri zalamovaní riadkov")
("when wrapping" "pri zalamovaní (wrapping)")
("while" "kým")
("white" "biela")
("whitespace" "biela medzera")
("wide" "široké")
("wide accent" "široký akcent")
("wide bar" "široký pruh")
("wide block" "široký blok")
("wide colored" "široký farebný")
("wide float" "široký plávajúci objekt")
("wide footnote" "široká poznámka pod čiarou")
("wide note" "široká poznámka")
("wide tabular" "široká tabuľka")
("widescreen" "široká obrazovka")
("width" "širka")
("width is exactly the specified width" "širka je presne zadaná")
("width is maximum of specified width and box width" "šírka je maximum zadanej šírky a šírky boxu")
("width is minimum of specified width and box width" "šírka je minimum zadanej šírky a šírky boxu")
("width magnification" "rozšírenie")
("window" "okno")
("window height" "výška okna")
("window width" "šírka okna")
("windows" "okná")
("windows key" "kláves 'Windows'")
("with" "s")
("with newer version" "s novšou verziou")
("with older version" "so staršou verziou")
("wood" "drevo")
("word count" "počet slov")
("wrap lines" "zalamovať riadky")
("write a macro" "napísať makro")
("write a name" "napísať meno")
("write bold mathematics" "použiť matematické hrubé písmo")
("write bold text" "použiť hrubé písmo")
("write italic text" "použiť kurzívu")
("write sample text" "pužiť písmo pre príklad")
("write strong text" "použiť silné písmo")
("write typewriter text" "použiť písmo 'písací stroj'")
("write verbatim text" "použiť písmo 'verbatim'")
("writing TeXmacs bibliography styles" "tvorba TeXmacs štýlov pre zoznam literatúry")
("writing data converters" "tvorba konvertorov dáť")
("writing documentation" "písanie dokumentácie")
("writing your own style files" "tvorba vašich vlastných súborov štýlov")
("written with TeXmacs" "napísané v TeXmacse")
("wrong empty passphrase" "nesprávne prázdne heslo")
("wrong passphrase" "nesprávne heslo")
("year" "rok")
("year, Name" "rok, Meno")
("yellow" "žltá")
("yes" "áno")
("you are attempting to open an encrypted file while" "pokúšate sa otvoriť zašifrovaný súbor kým")
("you can also obtain" "môžete tiež získať")
("you might consider enabling the experimental" "mohli by ste zvážiť zapnutie experimentálnych")
("you must add a bibliography file" "je potrebné pridať súbor literatúry")
("you should also make sure that GnuPG is installed" "uistite sa tiež, že je nainštalovaný program GnuPG")
("your document is back in its original state" "váš dokument je späť v pôvodnom stave")
("your first interface" "vaše prvé rozhranie")
("your language" "váš jazyk")
("your personal dictionary has been modified" "váš osobný slovník bol modifikovaný")
("zebra" "zebra")
("zigzag" "cik-cak")
("zoom" "zväčšenie")
("zoom factor" "faktor zväčšenia")
("zoom in" "priblížiť (zväčšiť)")
("zoom out" "oddialiť (zmenšiť)")
("zoom/unzoom objects" "priblížiť/zrušiť priblíženie objektov")